from typing import Literal, NewType

from sincpro_payments_sdk import exceptions
from sincpro_payments_sdk.shared.ddd import new_value_object

cities_grouped_by_country = {
    "AD": {
        "Andorra la Vella": "07",
        "Canillo": "02",
        "Encamp": "03",
        "Escaldes-Engordany": "08",
        "La Massana": "04",
        "Ordino": "05",
        "Sant Julia de Loria": "06",
    },
    "AE": {
        "'Ajman": "AJ",
        "Abu Zaby": "AZ",
        "Al Fujayrah": "FU",
        "Ash Shariqah": "SH",
        "Dubayy": "DU",
        "Ra's al Khaymah": "RK",
        "Umm al Qaywayn": "UQ",
    },
    "AF": {
        "Badakhshan": "BDS",
        "Baghlan": "BGL",
        "Balkh": "BAL",
        "Bamyan": "BAM",
        "Daykundi": "DAY",
        "Farah": "FRA",
        "Faryab": "FYB",
        "Ghazni": "GHA",
        "Ghor": "GHO",
        "Helmand": "HEL",
        "Herat": "HER",
        "Jowzjan": "JOW",
        "Kabul": "KAB",
        "Kandahar": "KAN",
        "Khost": "KHO",
        "Kunduz": "KDZ",
        "Laghman": "LAG",
        "Logar": "LOG",
        "Nangarhar": "NAN",
        "Nimroz": "NIM",
        "Paktiya": "PIA",
        "Parwan": "PAR",
        "Takhar": "TAK",
        "Uruzgan": "URU",
    },
    "AG": {
        "Redonda": "11",
        "Saint George": "03",
        "Saint John": "04",
        "Saint Mary": "05",
        "Saint Paul": "06",
        "Saint Peter": "07",
        "Saint Philip": "08",
    },
    "AI": {"Anguilla": ""},
    "AL": {
        "Berat": "01",
        "Diber": "09",
        "Durres": "02",
        "Elbasan": "03",
        "Fier": "04",
        "Gjirokaster": "05",
        "Korce": "06",
        "Kukes": "07",
        "Lezhe": "08",
        "Shkoder": "10",
        "Tirane": "11",
        "Vlore": "12",
    },
    "AM": {
        "Aragacotn": "AG",
        "Ararat": "AR",
        "Armavir": "AV",
        "Erevan": "ER",
        "Gegark'unik'": "GR",
        "Kotayk'": "KT",
        "Lori": "LO",
        "Sirak": "SH",
        "Syunik'": "SU",
        "Tavus": "TV",
        "Vayoc Jor": "VD",
    },
    "AO": {
        "Bengo": "BGO",
        "Benguela": "BGU",
        "Bie": "BIE",
        "Cabinda": "CAB",
        "Cunene": "CNN",
        "Huambo": "HUA",
        "Huila": "HUI",
        "Kuando Kubango": "CCU",
        "Kwanza Norte": "CNO",
        "Kwanza Sul": "CUS",
        "Luanda": "LUA",
        "Lunda Norte": "LNO",
        "Lunda Sul": "LSU",
        "Malange": "MAL",
        "Moxico": "MOX",
        "Namibe": "NAM",
        "Uige": "UIG",
        "Zaire": "ZAI",
    },
    "AR": {
        "Buenos Aires": "B",
        "Catamarca": "K",
        "Chaco": "H",
        "Chubut": "U",
        "Ciudad Autonoma de Buenos Aires": "C",
        "Cordoba": "X",
        "Corrientes": "W",
        "Entre Rios": "E",
        "Formosa": "P",
        "Jujuy": "Y",
        "La Pampa": "L",
        "La Rioja": "F",
        "Mendoza": "M",
        "Misiones": "N",
        "Neuquen": "Q",
        "Rio Negro": "R",
        "Salta": "A",
        "San Juan": "J",
        "San Luis": "D",
        "Santa Cruz": "Z",
        "Santa Fe": "S",
        "Santiago del Estero": "G",
        "Tierra del Fuego": "V",
        "Tucuman": "T",
    },
    "AS": {"Eastern District": "", "Western District": ""},
    "AT": {
        "Burgenland": "1",
        "Karnten": "2",
        "Niederosterreich": "3",
        "Oberosterreich": "4",
        "Salzburg": "5",
        "Steiermark": "6",
        "Tirol": "7",
        "Vorarlberg": "8",
        "Wien": "9",
    },
    "AU": {
        "Australian Capital Territory": "ACT",
        "New South Wales": "NSW",
        "Northern Territory": "NT",
        "Queensland": "QLD",
        "South Australia": "SA",
        "Tasmania": "TAS",
        "Victoria": "VIC",
        "Western Australia": "WA",
    },
    "AW": {"Aruba": ""},
    "AX": {
        "Eckeroe": "",
        "Finstroem": "",
        "Hammarland": "",
        "Jomala": "",
        "Mariehamn": "",
        "Saltvik": "",
        "Sund": "",
    },
    "AZ": {
        "Abseron": "ABS",
        "Agcabadi": "AGC",
        "Agstafa": "AGA",
        "Agsu": "AGU",
        "Astara": "AST",
        "Baki": "BA",
        "Balakan": "BAL",
        "Barda": "BAR",
        "Beylaqan": "BEY",
        "Bilasuvar": "BIL",
        "Calilabad": "CAL",
        "Fuzuli": "FUZ",
        "Gadabay": "GAD",
        "Ganca": "GA",
        "Goranboy": "GOR",
        "Goycay": "GOY",
        "Goygol": "GYG",
        "Haciqabul": "HAC",
        "Imisli": "IMI",
        "Ismayilli": "ISM",
        "Kurdamir": "KUR",
        "Lankaran": "LA",
        "Masalli": "MAS",
        "Mingacevir": "MI",
        "Naftalan": "NA",
        "Naxcivan": "NX",
        "Neftcala": "NEF",
        "Oguz": "OGU",
        "Qabala": "QAB",
        "Qax": "QAX",
        "Qazax": "QAZ",
        "Quba": "QBA",
        "Qusar": "QUS",
        "Saatli": "SAT",
        "Sabirabad": "SAB",
        "Saki": "SAK",
        "Salyan": "SAL",
        "Samaxi": "SMI",
        "Samkir": "SKR",
        "Samux": "SMX",
        "Sirvan": "SR",
        "Siyazan": "SIY",
        "Sumqayit": "SM",
        "Tartar": "TAR",
        "Tovuz": "TOV",
        "Xacmaz": "XAC",
        "Xizi": "XIZ",
        "Yardimli": "YAR",
        "Yevlax": "YEV",
        "Zaqatala": "ZAQ",
    },
    "BA": {
        "Brcko distrikt": "BRC",
        "Federacija Bosne i Hercegovine": "BIH",
        "Republika Srpska": "SRP",
    },
    "BB": {
        "Christ Church": "01",
        "Saint Andrew": "02",
        "Saint George": "03",
        "Saint James": "04",
        "Saint John": "05",
        "Saint Joseph": "06",
        "Saint Lucy": "07",
        "Saint Michael": "08",
        "Saint Peter": "09",
        "Saint Philip": "10",
        "Saint Thomas": "11",
    },
    "BD": {
        "Barisal": "A",
        "Chittagong": "B",
        "Dhaka": "C",
        "Khulna": "D",
        "Rajshahi": "E",
        "Rangpur": "F",
        "Sylhet": "G",
    },
    "BE": {
        "Antwerpen": "VAN",
        "Brabant wallon": "WBR",
        "Brussels Hoofdstedelijk Gewest": "BRU",
        "Hainaut": "WHT",
        "Liege": "WLG",
        "Limburg": "VLI",
        "Luxembourg": "WLX",
        "Namur": "WNA",
        "Oost-Vlaanderen": "VOV",
        "Vlaams-Brabant": "VBR",
        "West-Vlaanderen": "VWV",
    },
    "BF": {
        "Bale": "BAL",
        "Bam": "BAM",
        "Bazega": "BAZ",
        "Boulgou": "BLG",
        "Boulkiemde": "BLK",
        "Comoe": "COM",
        "Gnagna": "GNA",
        "Houet": "HOU",
        "Kadiogo": "KAD",
        "Kourweogo": "KOW",
        "Leraba": "LER",
        "Mouhoun": "MOU",
        "Poni": "PON",
        "Sanmatenga": "SMT",
        "Tapoa": "TAP",
        "Tuy": "TUI",
        "Yatenga": "YAT",
        "Zoundweogo": "ZOU",
    },
    "BG": {
        "Blagoevgrad": "01",
        "Burgas": "02",
        "Dobrich": "08",
        "Gabrovo": "07",
        "Haskovo": "26",
        "Kardzhali": "09",
        "Kyustendil": "10",
        "Lovech": "11",
        "Montana": "12",
        "Pazardzhik": "13",
        "Pernik": "14",
        "Pleven": "15",
        "Plovdiv": "16",
        "Razgrad": "17",
        "Ruse": "18",
        "Shumen": "27",
        "Silistra": "19",
        "Sliven": "20",
        "Smolyan": "21",
        "Sofia": "23",
        "Sofia (stolitsa)": "22",
        "Stara Zagora": "24",
        "Targovishte": "25",
        "Varna": "03",
        "Veliko Tarnovo": "04",
        "Vidin": "05",
        "Vratsa": "06",
        "Yambol": "28",
    },
    "BH": {
        "Al 'Asimah": "13",
        "Al Janubiyah": "14",
        "Al Muharraq": "15",
        "Ash Shamaliyah": "17",
    },
    "BI": {
        "Bubanza": "BB",
        "Bujumbura Mairie": "BM",
        "Bururi": "BR",
        "Cibitoke": "CI",
        "Gitega": "GI",
        "Kirundo": "KI",
        "Muramvya": "MU",
        "Mwaro": "MW",
        "Ngozi": "NG",
        "Rutana": "RT",
        "Ruyigi": "RY",
    },
    "BJ": {
        "Alibori": "AL",
        "Atacora": "AK",
        "Atlantique": "AQ",
        "Borgou": "BO",
        "Donga": "DO",
        "Littoral": "LI",
        "Mono": "MO",
        "Oueme": "OU",
        "Plateau": "PL",
        "Zou": "ZO",
    },
    "BL": {"Saint Barthelemy": ""},
    "BM": {"Hamilton": "", "Saint George": ""},
    "BN": {"Belait": "BE", "Brunei-Muara": "BM", "Temburong": "TE", "Tutong": "TU"},
    "BO": {
        "Chuquisaca": "H",
        "Cochabamba": "C",
        "El Beni": "B",
        "La Paz": "L",
        "Oruro": "O",
        "Pando": "N",
        "Potosi": "P",
        "Santa Cruz": "S",
        "Tarija": "T",
    },
    "BQ": {"Bonaire": "BO", "Saba": "SA", "Sint Eustatius": "SE"},
    "BR": {
        "Acre": "AC",
        "Alagoas": "AL",
        "Amapa": "AP",
        "Amazonas": "AM",
        "Bahia": "BA",
        "Ceara": "CE",
        "Distrito Federal": "DF",
        "Espirito Santo": "ES",
        "Goias": "GO",
        "Maranhao": "MA",
        "Mato Grosso": "MT",
        "Mato Grosso do Sul": "MS",
        "Minas Gerais": "MG",
        "Para": "PA",
        "Paraiba": "PB",
        "Parana": "PR",
        "Pernambuco": "PE",
        "Piaui": "PI",
        "Rio Grande do Norte": "RN",
        "Rio Grande do Sul": "RS",
        "Rio de Janeiro": "RJ",
        "Rondonia": "RO",
        "Roraima": "RR",
        "Santa Catarina": "SC",
        "Sao Paulo": "SP",
        "Sergipe": "SE",
        "Tocantins": "TO",
    },
    "BS": {
        "Central Andros": "CS",
        "City of Freeport": "FP",
        "Harbour Island": "HI",
        "Hope Town": "HT",
        "Long Island": "LI",
        "New Providence": "NP",
        "South Eleuthera": "SE",
    },
    "BT": {
        "Bumthang": "33",
        "Chhukha": "12",
        "Gasa": "GA",
        "Haa": "13",
        "Lhuentse": "44",
        "Monggar": "42",
        "Paro": "11",
        "Pemagatshel": "43",
        "Punakha": "23",
        "Samdrup Jongkhar": "45",
        "Samtse": "14",
        "Thimphu": "15",
        "Trashigang": "41",
        "Trongsa": "32",
        "Tsirang": "21",
        "Wangdue Phodrang": "24",
    },
    "BW": {
        "Central": "CE",
        "Kgalagadi": "KG",
        "Kgatleng": "KL",
        "Kweneng": "KW",
        "North East": "NE",
        "North West": "NW",
        "South East": "SE",
        "Southern": "SO",
    },
    "BY": {
        "Brestskaya voblasts'": "BR",
        "Homyel'skaya voblasts'": "HO",
        "Horad Minsk": "HM",
        "Hrodzenskaya voblasts'": "HR",
        "Mahilyowskaya voblasts'": "MA",
        "Minskaya voblasts'": "MI",
        "Vitsyebskaya voblasts'": "VI",
    },
    "BZ": {
        "Belize": "BZ",
        "Cayo": "CY",
        "Corozal": "CZL",
        "Orange Walk": "OW",
        "Stann Creek": "SC",
        "Toledo": "TOL",
    },
    "CA": {
        "Alberta": "AB",
        "British Columbia": "BC",
        "Manitoba": "MB",
        "New Brunswick": "NB",
        "Newfoundland and Labrador": "NL",
        "Northwest Territories": "NT",
        "Nova Scotia": "NS",
        "Nunavut": "NU",
        "Ontario": "ON",
        "Prince Edward Island": "PE",
        "Quebec": "QC",
        "Saskatchewan": "SK",
        "Yukon": "YT",
    },
    "CD": {
        "Equateur": "EQ",
        "Haut-Katanga": "HK",
        "Haut-Lomami": "HL",
        "Haut-Uele": "HU",
        "Ituri": "IT",
        "Kasai Central": "KC",
        "Kasai Oriental": "KE",
        "Kinshasa": "KN",
        "Kongo Central": "BC",
        "Kwilu": "KL",
        "Lualaba": "LU",
        "Maniema": "MA",
        "Nord-Kivu": "NK",
        "Nord-Ubangi": "NU",
        "Sankuru": "SA",
        "Sud-Kivu": "SK",
        "Sud-Ubangi": "SU",
        "Tanganyika": "TA",
        "Tshopo": "TO",
        "Tshuapa": "TU",
    },
    "CF": {"Bangui": "BGF", "Nana-Mambere": "NM", "Ouham": "AC", "Ouham-Pende": "OP"},
    "CG": {"Brazzaville": "BZV", "Cuvette-Ouest": "15", "Pointe-Noire": "16", "Sangha": "13"},
    "CH": {
        "Aargau": "AG",
        "Appenzell Ausserrhoden": "AR",
        "Appenzell Innerrhoden": "AI",
        "Basel-Landschaft": "BL",
        "Basel-Stadt": "BS",
        "Bern": "BE",
        "Fribourg": "FR",
        "Geneve": "GE",
        "Glarus": "GL",
        "Graubunden": "GR",
        "Jura": "JU",
        "Luzern": "LU",
        "Neuchatel": "NE",
        "Nidwalden": "NW",
        "Obwalden": "OW",
        "Sankt Gallen": "SG",
        "Schaffhausen": "SH",
        "Schwyz": "SZ",
        "Solothurn": "SO",
        "Thurgau": "TG",
        "Ticino": "TI",
        "Uri": "UR",
        "Valais": "VS",
        "Vaud": "VD",
        "Zug": "ZG",
        "Zurich": "ZH",
    },
    "CI": {
        "Abidjan": "AB",
        "Bas-Sassandra": "BS",
        "Comoe": "CM",
        "Denguele": "DN",
        "Goh-Djiboua": "GD",
        "Lacs": "LC",
        "Lagunes": "LG",
        "Montagnes": "MG",
        "Sassandra-Marahoue": "SM",
        "Savanes": "SV",
        "Vallee du Bandama": "VB",
        "Woroba": "WR",
        "Yamoussoukro": "YM",
        "Zanzan": "ZZ",
    },
    "CK": {"Cook Islands": ""},
    "CL": {
        "Aisen del General Carlos Ibanez del Campo": "AI",
        "Antofagasta": "AN",
        "Arica y Parinacota": "AP",
        "Atacama": "AT",
        "Biobio": "BI",
        "Coquimbo": "CO",
        "La Araucania": "AR",
        "Libertador General Bernardo O'Higgins": "LI",
        "Los Lagos": "LL",
        "Los Rios": "LR",
        "Magallanes": "MA",
        "Maule": "ML",
        "Region Metropolitana de Santiago": "RM",
        "Tarapaca": "TA",
        "Valparaiso": "VS",
    },
    "CM": {
        "Adamaoua": "AD",
        "Centre": "CE",
        "Est": "ES",
        "Extreme-Nord": "EN",
        "Littoral": "LT",
        "Nord": "NO",
        "Nord-Ouest": "NW",
        "Ouest": "OU",
        "Sud": "SU",
        "Sud-Ouest": "SW",
    },
    "CN": {
        "Anhui": "AH",
        "Beijing": "BJ",
        "Chongqing": "CQ",
        "Fujian": "FJ",
        "Gansu": "GS",
        "Guangdong": "GD",
        "Guangxi": "GX",
        "Guizhou": "GZ",
        "Hainan": "HI",
        "Hebei": "HE",
        "Heilongjiang": "HL",
        "Henan": "HA",
        "Hubei": "HB",
        "Hunan": "HN",
        "Jiangsu": "JS",
        "Jiangxi": "JX",
        "Jilin": "JL",
        "Liaoning": "LN",
        "Nei Mongol": "NM",
        "Ningxia": "NX",
        "Qinghai": "QH",
        "Shaanxi": "SN",
        "Shandong": "SD",
        "Shanghai": "SH",
        "Shanxi": "SX",
        "Sichuan": "SC",
        "Tianjin": "TJ",
        "Xinjiang": "XJ",
        "Xizang": "XZ",
        "Yunnan": "YN",
        "Zhejiang": "ZJ",
    },
    "CO": {
        "Amazonas": "AMA",
        "Antioquia": "ANT",
        "Arauca": "ARA",
        "Atlantico": "ATL",
        "Bolivar": "BOL",
        "Boyaca": "BOY",
        "Caldas": "CAL",
        "Caqueta": "CAQ",
        "Casanare": "CAS",
        "Cauca": "CAU",
        "Cesar": "CES",
        "Choco": "CHO",
        "Cordoba": "COR",
        "Cundinamarca": "CUN",
        "Distrito Capital de Bogota": "DC",
        "Guainia": "GUA",
        "Guaviare": "GUV",
        "Huila": "HUI",
        "La Guajira": "LAG",
        "Magdalena": "MAG",
        "Meta": "MET",
        "Narino": "NAR",
        "Norte de Santander": "NSA",
        "Putumayo": "PUT",
        "Quindio": "QUI",
        "Risaralda": "RIS",
        "San Andres, Providencia y Santa Catalina": "SAP",
        "Santander": "SAN",
        "Sucre": "SUC",
        "Tolima": "TOL",
        "Valle del Cauca": "VAC",
        "Vichada": "VID",
    },
    "CR": {
        "Alajuela": "A",
        "Cartago": "C",
        "Guanacaste": "G",
        "Heredia": "H",
        "Limon": "L",
        "Puntarenas": "P",
        "San Jose": "SJ",
    },
    "CU": {
        "Artemisa": "15",
        "Camaguey": "09",
        "Ciego de Avila": "08",
        "Cienfuegos": "06",
        "Granma": "12",
        "Guantanamo": "14",
        "Holguin": "11",
        "Isla de la Juventud": "99",
        "La Habana": "03",
        "Las Tunas": "10",
        "Matanzas": "04",
        "Mayabeque": "16",
        "Pinar del Rio": "01",
        "Sancti Spiritus": "07",
        "Santiago de Cuba": "13",
        "Villa Clara": "05",
    },
    "CV": {
        "Boa Vista": "BV",
        "Porto Novo": "PN",
        "Praia": "PR",
        "Ribeira Grande": "RG",
        "Sal": "SL",
        "Sao Filipe": "SF",
        "Sao Vicente": "SV",
        "Tarrafal": "TA",
    },
    "CW": {"Curacao": ""},
    "CY": {
        "Ammochostos": "04",
        "Keryneia": "06",
        "Larnaka": "03",
        "Lefkosia": "01",
        "Lemesos": "02",
        "Pafos": "05",
    },
    "CZ": {
        "Jihocesky kraj": "31",
        "Jihomoravsky kraj": "64",
        "Karlovarsky kraj": "41",
        "Kraj Vysocina": "63",
        "Kralovehradecky kraj": "52",
        "Liberecky kraj": "51",
        "Moravskoslezsky kraj": "80",
        "Olomoucky kraj": "71",
        "Pardubicky kraj": "53",
        "Plzensky kraj": "32",
        "Praha, Hlavni mesto": "10",
        "Stredocesky kraj": "20",
        "Ustecky kraj": "42",
        "Zlinsky kraj": "72",
    },
    "DE": {
        "Baden-Wurttemberg": "BW",
        "Bayern": "BY",
        "Berlin": "BE",
        "Brandenburg": "BB",
        "Bremen": "HB",
        "Hamburg": "HH",
        "Hessen": "HE",
        "Mecklenburg-Vorpommern": "MV",
        "Niedersachsen": "NI",
        "Nordrhein-Westfalen": "NW",
        "Rheinland-Pfalz": "RP",
        "Saarland": "SL",
        "Sachsen": "SN",
        "Sachsen-Anhalt": "ST",
        "Schleswig-Holstein": "SH",
        "Thuringen": "TH",
    },
    "DJ": {"Djibouti": "DJ"},
    "DK": {
        "Hovedstaden": "84",
        "Midtjylland": "82",
        "Nordjylland": "81",
        "Sjaelland": "85",
        "Syddanmark": "83",
    },
    "DM": {
        "Saint Andrew": "02",
        "Saint David": "03",
        "Saint George": "04",
        "Saint John": "05",
        "Saint Luke": "07",
        "Saint Mark": "08",
        "Saint Patrick": "09",
        "Saint Paul": "10",
    },
    "DO": {
        "Azua": "02",
        "Baoruco": "03",
        "Barahona": "04",
        "Dajabon": "05",
        "Distrito Nacional (Santo Domingo)": "01",
        "Duarte": "06",
        "El Seibo": "08",
        "Elias Pina": "07",
        "Espaillat": "09",
        "Hato Mayor": "30",
        "Hermanas Mirabal": "19",
        "Independencia": "10",
        "La Altagracia": "11",
        "La Romana": "12",
        "La Vega": "13",
        "Maria Trinidad Sanchez": "14",
        "Monsenor Nouel": "28",
        "Monte Cristi": "15",
        "Monte Plata": "29",
        "Peravia": "17",
        "Puerto Plata": "18",
        "Samana": "20",
        "San Cristobal": "21",
        "San Jose de Ocoa": "31",
        "San Juan": "22",
        "San Pedro de Macoris": "23",
        "Sanchez Ramirez": "24",
        "Santiago": "25",
        "Santiago Rodriguez": "26",
        "Valverde": "27",
    },
    "DZ": {
        "Adrar": "01",
        "Ain Defla": "44",
        "Ain Temouchent": "46",
        "Alger": "16",
        "Annaba": "23",
        "Batna": "05",
        "Bechar": "08",
        "Bejaia": "06",
        "Biskra": "07",
        "Blida": "09",
        "Bordj Bou Arreridj": "34",
        "Bouira": "10",
        "Boumerdes": "35",
        "Chlef": "02",
        "Constantine": "25",
        "Djelfa": "17",
        "El Bayadh": "32",
        "El Oued": "39",
        "El Tarf": "36",
        "Ghardaia": "47",
        "Guelma": "24",
        "Illizi": "33",
        "Jijel": "18",
        "Khenchela": "40",
        "Laghouat": "03",
        "M'sila": "28",
        "Mascara": "29",
        "Medea": "26",
        "Mila": "43",
        "Mostaganem": "27",
        "Naama": "45",
        "Oran": "31",
        "Ouargla": "30",
        "Oum el Bouaghi": "04",
        "Relizane": "48",
        "Saida": "20",
        "Setif": "19",
        "Sidi Bel Abbes": "22",
        "Skikda": "21",
        "Souk Ahras": "41",
        "Tamanrasset": "11",
        "Tebessa": "12",
        "Tiaret": "14",
        "Tindouf": "37",
        "Tipaza": "42",
        "Tissemsilt": "38",
        "Tizi Ouzou": "15",
        "Tlemcen": "13",
    },
    "EC": {
        "Azuay": "A",
        "Bolivar": "B",
        "Canar": "F",
        "Carchi": "C",
        "Chimborazo": "H",
        "Cotopaxi": "X",
        "El Oro": "O",
        "Esmeraldas": "E",
        "Galapagos": "W",
        "Guayas": "G",
        "Imbabura": "I",
        "Loja": "L",
        "Los Rios": "R",
        "Manabi": "M",
        "Morona Santiago": "S",
        "Napo": "N",
        "Orellana": "D",
        "Pastaza": "Y",
        "Pichincha": "P",
        "Santa Elena": "SE",
        "Santo Domingo de los Tsachilas": "SD",
        "Sucumbios": "U",
        "Tungurahua": "T",
        "Zamora Chinchipe": "Z",
    },
    "EE": {
        "Harjumaa": "37",
        "Hiiumaa": "39",
        "Ida-Virumaa": "44",
        "Jarvamaa": "51",
        "Jogevamaa": "49",
        "Laane-Virumaa": "59",
        "Laanemaa": "57",
        "Parnumaa": "67",
        "Polvamaa": "65",
        "Raplamaa": "70",
        "Saaremaa": "74",
        "Tartumaa": "78",
        "Valgamaa": "82",
        "Viljandimaa": "84",
        "Vorumaa": "86",
    },
    "EG": {
        "Ad Daqahliyah": "DK",
        "Al Bahr al Ahmar": "BA",
        "Al Buhayrah": "BH",
        "Al Fayyum": "FYM",
        "Al Gharbiyah": "GH",
        "Al Iskandariyah": "ALX",
        "Al Isma'iliyah": "IS",
        "Al Jizah": "GZ",
        "Al Minufiyah": "MNF",
        "Al Minya": "MN",
        "Al Qahirah": "C",
        "Al Qalyubiyah": "KB",
        "Al Uqsur": "LX",
        "Al Wadi al Jadid": "WAD",
        "As Suways": "SUZ",
        "Ash Sharqiyah": "SHR",
        "Aswan": "ASN",
        "Asyut": "AST",
        "Bani Suwayf": "BNS",
        "Bur Sa'id": "PTS",
        "Dumyat": "DT",
        "Janub Sina'": "JS",
        "Kafr ash Shaykh": "KFS",
        "Matruh": "MT",
        "Qina": "KN",
        "Shamal Sina'": "SIN",
        "Suhaj": "SHG",
    },
    "ER": {"Al Awsat": "MA"},
    "ES": {
        "Andalucia": "AN",
        "Aragon": "AR",
        "Asturias, Principado de": "AS",
        "Canarias": "CN",
        "Cantabria": "CB",
        "Castilla y Leon": "CL",
        "Castilla-La Mancha": "CM",
        "Catalunya": "CT",
        "Ceuta": "CE",
        "Extremadura": "EX",
        "Galicia": "GA",
        "Illes Balears": "IB",
        "La Rioja": "RI",
        "Madrid, Comunidad de": "MD",
        "Melilla": "ML",
        "Murcia, Region de": "MC",
        "Navarra, Comunidad Foral de": "NC",
        "Pais Vasco": "PV",
        "Valenciana, Comunidad": "VC",
    },
    "ET": {
        "Adis Abeba": "AA",
        "Afar": "AF",
        "Amara": "AM",
        "Binshangul Gumuz": "BE",
        "Hareri Hizb": "HA",
        "Oromiya": "OR",
        "Sumale": "SO",
        "Tigray": "TI",
        "YeDebub Biheroch Bihereseboch na Hizboch": "SN",
    },
    "FI": {
        "Etela-Karjala": "02",
        "Etela-Pohjanmaa": "03",
        "Etela-Savo": "04",
        "Kainuu": "05",
        "Kanta-Hame": "06",
        "Keski-Pohjanmaa": "07",
        "Keski-Suomi": "08",
        "Kymenlaakso": "09",
        "Lappi": "10",
        "Paijat-Hame": "16",
        "Pirkanmaa": "11",
        "Pohjanmaa": "12",
        "Pohjois-Karjala": "13",
        "Pohjois-Pohjanmaa": "14",
        "Pohjois-Savo": "15",
        "Satakunta": "17",
        "Uusimaa": "18",
        "Varsinais-Suomi": "19",
    },
    "FJ": {"Central": "C", "Eastern": "E", "Northern": "N", "Rotuma": "R", "Western": "W"},
    "FK": {"Falkland Islands (Malvinas)": ""},
    "FM": {"Chuuk": "TRK", "Kosrae": "KSA", "Pohnpei": "PNI", "Yap": "YAP"},
    "FO": {"Eysturoy": "", "Nordoyar": "", "Streymoy": "", "Suduroy": "", "Vagar": ""},
    "FR": {
        "Auvergne-Rhone-Alpes": "ARA",
        "Bourgogne-Franche-Comte": "BFC",
        "Bretagne": "BRE",
        "Centre-Val de Loire": "CVL",
        "Corse": "COR",
        "Grand-Est": "GES",
        "Hauts-de-France": "HDF",
        "Ile-de-France": "IDF",
        "Normandie": "NOR",
        "Nouvelle-Aquitaine": "NAQ",
        "Occitanie": "OCC",
        "Pays-de-la-Loire": "PDL",
        "Provence-Alpes-Cote-d'Azur": "PAC",
    },
    "GA": {
        "Estuaire": "1",
        "Haut-Ogooue": "2",
        "Moyen-Ogooue": "3",
        "Ngounie": "4",
        "Ogooue-Ivindo": "6",
        "Ogooue-Maritime": "8",
        "Woleu-Ntem": "9",
    },
    "GB": {"England": "ENG", "Northern Ireland": "NIR", "Scotland": "SCT", "Wales": "WLS"},
    "GD": {
        "Saint Andrew": "01",
        "Saint David": "02",
        "Saint George": "03",
        "Saint John": "04",
        "Saint Mark": "05",
        "Saint Patrick": "06",
        "Southern Grenadine Islands": "10",
    },
    "GE": {
        "Abkhazia": "AB",
        "Ajaria": "AJ",
        "Guria": "GU",
        "Imereti": "IM",
        "K'akheti": "KA",
        "Kvemo Kartli": "KK",
        "Mtskheta-Mtianeti": "MM",
        "Rach'a-Lechkhumi-Kvemo Svaneti": "RL",
        "Samegrelo-Zemo Svaneti": "SZ",
        "Samtskhe-Javakheti": "SJ",
        "Shida Kartli": "SK",
        "Tbilisi": "TB",
    },
    "GF": {"Guyane": ""},
    "GG": {"Guernsey": ""},
    "GH": {
        "Ashanti": "AH",
        "Brong-Ahafo": "BA",
        "Central": "CP",
        "Eastern": "EP",
        "Greater Accra": "AA",
        "Northern": "NP",
        "Upper East": "UE",
        "Volta": "TV",
        "Western": "WP",
    },
    "GI": {"Gibraltar": ""},
    "GL": {
        "Avannaata Kommunia": "AV",
        "Kommune Kujalleq": "KU",
        "Kommune Qeqertalik": "QT",
        "Kommuneqarfik Sermersooq": "SM",
        "Qeqqata Kommunia": "QE",
    },
    "GM": {
        "Banjul": "B",
        "Central River": "M",
        "Lower River": "L",
        "North Bank": "N",
        "Upper River": "U",
        "Western": "W",
    },
    "GN": {
        "Boffa": "BF",
        "Boke": "B",
        "Conakry": "C",
        "Coyah": "CO",
        "Dabola": "DB",
        "Dalaba": "DL",
        "Dubreka": "DU",
        "Kankan": "K",
        "Kissidougou": "KS",
        "Labe": "L",
        "Macenta": "MC",
        "Nzerekore": "N",
        "Siguiri": "SI",
    },
    "GP": {"Guadeloupe": ""},
    "GQ": {"Bioko Norte": "BN", "Bioko Sur": "BS", "Litoral": "LI", "Wele-Nzas": "WN"},
    "GR": {
        "Anatoliki Makedonia kai Thraki": "A",
        "Attiki": "I",
        "Dytiki Ellada": "G",
        "Dytiki Makedonia": "C",
        "Ionia Nisia": "F",
        "Ipeiros": "D",
        "Kentriki Makedonia": "B",
        "Kriti": "M",
        "Notio Aigaio": "L",
        "Peloponnisos": "J",
        "Sterea Ellada": "H",
        "Thessalia": "E",
        "Voreio Aigaio": "K",
    },
    "GT": {
        "Alta Verapaz": "AV",
        "Baja Verapaz": "BV",
        "Chimaltenango": "CM",
        "Chiquimula": "CQ",
        "El Progreso": "PR",
        "Escuintla": "ES",
        "Guatemala": "GU",
        "Huehuetenango": "HU",
        "Izabal": "IZ",
        "Jalapa": "JA",
        "Jutiapa": "JU",
        "Peten": "PE",
        "Quetzaltenango": "QZ",
        "Quiche": "QC",
        "Retalhuleu": "RE",
        "Sacatepequez": "SA",
        "San Marcos": "SM",
        "Santa Rosa": "SR",
        "Solola": "SO",
        "Suchitepequez": "SU",
        "Totonicapan": "TO",
        "Zacapa": "ZA",
    },
    "GU": {
        "Agat": "",
        "Barrigada": "",
        "Chalan Pago-Ordot": "",
        "Dededo": "",
        "Hagatna": "",
        "Mangilao": "",
        "Mongmong-Toto-Maite": "",
        "Piti": "",
        "Santa Rita": "",
        "Sinajana": "",
        "Tamuning-Tumon-Harmon": "",
        "Yigo": "",
        "Yona": "",
    },
    "GW": {"Bissau": "BS", "Gabu": "GA"},
    "GY": {
        "Barima-Waini": "BA",
        "Demerara-Mahaica": "DE",
        "East Berbice-Corentyne": "EB",
        "Essequibo Islands-West Demerara": "ES",
        "Mahaica-Berbice": "MA",
        "Pomeroon-Supenaam": "PM",
        "Potaro-Siparuni": "PT",
        "Upper Demerara-Berbice": "UD",
    },
    "HK": {"Hong Kong": ""},
    "HN": {
        "Atlantida": "AT",
        "Choluteca": "CH",
        "Colon": "CL",
        "Comayagua": "CM",
        "Copan": "CP",
        "Cortes": "CR",
        "El Paraiso": "EP",
        "Francisco Morazan": "FM",
        "Intibuca": "IN",
        "Islas de la Bahia": "IB",
        "La Paz": "LP",
        "Lempira": "LE",
        "Ocotepeque": "OC",
        "Olancho": "OL",
        "Santa Barbara": "SB",
        "Valle": "VA",
        "Yoro": "YO",
    },
    "HR": {
        "Bjelovarsko-bilogorska zupanija": "07",
        "Brodsko-posavska zupanija": "12",
        "Dubrovacko-neretvanska zupanija": "19",
        "Grad Zagreb": "21",
        "Istarska zupanija": "18",
        "Karlovacka zupanija": "04",
        "Koprivnicko-krizevacka zupanija": "06",
        "Krapinsko-zagorska zupanija": "02",
        "Licko-senjska zupanija": "09",
        "Medimurska zupanija": "20",
        "Osjecko-baranjska zupanija": "14",
        "Pozesko-slavonska zupanija": "11",
        "Primorsko-goranska zupanija": "08",
        "Sibensko-kninska zupanija": "15",
        "Sisacko-moslavacka zupanija": "03",
        "Splitsko-dalmatinska zupanija": "17",
        "Varazdinska zupanija": "05",
        "Viroviticko-podravska zupanija": "10",
        "Vukovarsko-srijemska zupanija": "16",
        "Zadarska zupanija": "13",
        "Zagrebacka zupanija": "01",
    },
    "HT": {
        "Artibonite": "AR",
        "Centre": "CE",
        "Grande'Anse": "GA",
        "Nord": "ND",
        "Ouest": "OU",
        "Sud": "SD",
        "Sud-Est": "SE",
    },
    "HU": {
        "Bacs-Kiskun": "BK",
        "Baranya": "BA",
        "Bekes": "BE",
        "Borsod-Abauj-Zemplen": "BZ",
        "Budapest": "BU",
        "Csongrad": "CS",
        "Fejer": "FE",
        "Gyor-Moson-Sopron": "GS",
        "Hajdu-Bihar": "HB",
        "Heves": "HE",
        "Jasz-Nagykun-Szolnok": "JN",
        "Komarom-Esztergom": "KE",
        "Nograd": "NO",
        "Pest": "PE",
        "Somogy": "SO",
        "Szabolcs-Szatmar-Bereg": "SZ",
        "Tolna": "TO",
        "Vas": "VA",
        "Veszprem": "VE",
        "Zala": "ZA",
    },
    "ID": {
        "Aceh": "AC",
        "Bali": "BA",
        "Banten": "BT",
        "Bengkulu": "BE",
        "Gorontalo": "GO",
        "Jakarta Raya": "JK",
        "Jambi": "JA",
        "Jawa Barat": "JB",
        "Jawa Tengah": "JT",
        "Jawa Timur": "JI",
        "Kalimantan Barat": "KB",
        "Kalimantan Selatan": "KS",
        "Kalimantan Tengah": "KT",
        "Kalimantan Timur": "KI",
        "Kalimantan Utara": "KU",
        "Kepulauan Bangka Belitung": "BB",
        "Kepulauan Riau": "KR",
        "Lampung": "LA",
        "Maluku": "ML",
        "Maluku Utara": "MU",
        "Nusa Tenggara Barat": "NB",
        "Nusa Tenggara Timur": "NT",
        "Papua": "PP",
        "Papua Barat": "PB",
        "Riau": "RI",
        "Sulawesi Barat": "SR",
        "Sulawesi Selatan": "SN",
        "Sulawesi Tengah": "ST",
        "Sulawesi Tenggara": "SG",
        "Sulawesi Utara": "SA",
        "Sumatera Barat": "SB",
        "Sumatera Selatan": "SS",
        "Sumatera Utara": "SU",
        "Yogyakarta": "YO",
    },
    "IE": {
        "Carlow": "CW",
        "Cavan": "CN",
        "Clare": "CE",
        "Cork": "CO",
        "Donegal": "DL",
        "Dublin": "D",
        "Galway": "G",
        "Kerry": "KY",
        "Kildare": "KE",
        "Kilkenny": "KK",
        "Laois": "LS",
        "Leitrim": "LM",
        "Limerick": "LK",
        "Longford": "LD",
        "Louth": "LH",
        "Mayo": "MO",
        "Meath": "MH",
        "Monaghan": "MN",
        "Offaly": "OY",
        "Roscommon": "RN",
        "Sligo": "SO",
        "Tipperary": "TA",
        "Waterford": "WD",
        "Westmeath": "WH",
        "Wexford": "WX",
        "Wicklow": "WW",
    },
    "IL": {
        "HaDarom": "D",
        "HaMerkaz": "M",
        "HaTsafon": "Z",
        "Hefa": "HA",
        "Tel Aviv": "TA",
        "Yerushalayim": "JM",
    },
    "IM": {"Isle of Man": ""},
    "IN": {
        "Andaman and Nicobar Islands": "AN",
        "Andhra Pradesh": "AP",
        "Arunachal Pradesh": "AR",
        "Assam": "AS",
        "Bihar": "BR",
        "Chandigarh": "CH",
        "Chhattisgarh": "CT",
        "Dadra and Nagar Haveli": "DN",
        "Daman and Diu": "DD",
        "Delhi": "DL",
        "Goa": "GA",
        "Gujarat": "GJ",
        "Haryana": "HR",
        "Himachal Pradesh": "HP",
        "Jammu and Kashmir": "JK",
        "Jharkhand": "JH",
        "Karnataka": "KA",
        "Kerala": "KL",
        "Lakshadweep": "LD",
        "Madhya Pradesh": "MP",
        "Maharashtra": "MH",
        "Manipur": "MN",
        "Meghalaya": "ML",
        "Mizoram": "MZ",
        "Nagaland": "NL",
        "Odisha": "OR",
        "Puducherry": "PY",
        "Punjab": "PB",
        "Rajasthan": "RJ",
        "Sikkim": "SK",
        "Tamil Nadu": "TN",
        "Telangana": "TG",
        "Tripura": "TR",
        "Uttar Pradesh": "UP",
        "Uttarakhand": "UT",
        "West Bengal": "WB",
    },
    "IO": {"British Indian Ocean Territory": ""},
    "IQ": {
        "Al Anbar": "AN",
        "Al Basrah": "BA",
        "Al Muthanna": "MU",
        "Al Qadisiyah": "QA",
        "An Najaf": "NA",
        "Arbil": "AR",
        "As Sulaymaniyah": "SU",
        "Babil": "BB",
        "Baghdad": "BG",
        "Dahuk": "DA",
        "Dhi Qar": "DQ",
        "Diyala": "DI",
        "Karbala'": "KA",
        "Kirkuk": "KI",
        "Maysan": "MA",
        "Ninawa": "NI",
        "Salah ad Din": "SD",
        "Wasit": "WA",
    },
    "IR": {
        "Alborz": "32",
        "Ardabil": "03",
        "Azarbayjan-e Gharbi": "02",
        "Azarbayjan-e Sharqi": "01",
        "Bushehr": "06",
        "Chahar Mahal va Bakhtiari": "08",
        "Esfahan": "04",
        "Fars": "14",
        "Gilan": "19",
        "Golestan": "27",
        "Hamadan": "24",
        "Hormozgan": "23",
        "Ilam": "05",
        "Kerman": "15",
        "Kermanshah": "17",
        "Khorasan-e Jonubi": "29",
        "Khorasan-e Razavi": "30",
        "Khorasan-e Shomali": "31",
        "Khuzestan": "10",
        "Kohgiluyeh va Bowyer Ahmad": "18",
        "Kordestan": "16",
        "Lorestan": "20",
        "Markazi": "22",
        "Mazandaran": "21",
        "Qazvin": "28",
        "Qom": "26",
        "Semnan": "12",
        "Sistan va Baluchestan": "13",
        "Tehran": "07",
        "Yazd": "25",
        "Zanjan": "11",
    },
    "IS": {
        "Austurland": "7",
        "Hofudborgarsvaedi": "1",
        "Nordurland eystra": "6",
        "Nordurland vestra": "5",
        "Sudurland": "8",
        "Sudurnes": "2",
        "Vestfirdir": "4",
        "Vesturland": "3",
    },
    "IT": {
        "Abruzzo": "65",
        "Basilicata": "77",
        "Calabria": "78",
        "Campania": "72",
        "Emilia-Romagna": "45",
        "Friuli-Venezia Giulia": "36",
        "Lazio": "62",
        "Liguria": "42",
        "Lombardia": "25",
        "Marche": "57",
        "Molise": "67",
        "Piemonte": "21",
        "Puglia": "75",
        "Sardegna": "88",
        "Sicilia": "82",
        "Toscana": "52",
        "Trentino-Alto Adige": "32",
        "Umbria": "55",
        "Valle d'Aosta": "23",
        "Veneto": "34",
    },
    "JE": {"Jersey": ""},
    "JM": {
        "Clarendon": "13",
        "Hanover": "09",
        "Kingston": "01",
        "Manchester": "12",
        "Portland": "04",
        "Saint Andrew": "02",
        "Saint Ann": "06",
        "Saint Catherine": "14",
        "Saint Elizabeth": "11",
        "Saint James": "08",
        "Saint Mary": "05",
        "Saint Thomas": "03",
        "Trelawny": "07",
        "Westmoreland": "10",
    },
    "JO": {
        "'Ajlun": "AJ",
        "Al 'Aqabah": "AQ",
        "Al 'Asimah": "AM",
        "Al Balqa'": "BA",
        "Al Karak": "KA",
        "Al Mafraq": "MA",
        "Az Zarqa'": "AZ",
        "Irbid": "IR",
        "Jarash": "JA",
        "Ma'an": "MN",
        "Madaba": "MD",
    },
    "JP": {
        "Aichi": "23",
        "Akita": "05",
        "Aomori": "02",
        "Chiba": "12",
        "Ehime": "38",
        "Fukui": "18",
        "Fukuoka": "40",
        "Fukushima": "07",
        "Gifu": "21",
        "Gunma": "10",
        "Hiroshima": "34",
        "Hokkaido": "01",
        "Hyogo": "28",
        "Ibaraki": "08",
        "Ishikawa": "17",
        "Iwate": "03",
        "Kagawa": "37",
        "Kagoshima": "46",
        "Kanagawa": "14",
        "Kochi": "39",
        "Kumamoto": "43",
        "Kyoto": "26",
        "Mie": "24",
        "Miyagi": "04",
        "Miyazaki": "45",
        "Nagano": "20",
        "Nagasaki": "42",
        "Nara": "29",
        "Niigata": "15",
        "Oita": "44",
        "Okayama": "33",
        "Okinawa": "47",
        "Osaka": "27",
        "Saga": "41",
        "Saitama": "11",
        "Shiga": "25",
        "Shimane": "32",
        "Shizuoka": "22",
        "Tochigi": "09",
        "Tokushima": "36",
        "Tokyo": "13",
        "Tottori": "31",
        "Toyama": "16",
        "Wakayama": "30",
        "Yamagata": "06",
        "Yamaguchi": "35",
        "Yamanashi": "19",
    },
    "KE": {
        "Baringo": "01",
        "Bomet": "02",
        "Bungoma": "03",
        "Busia": "04",
        "Elgeyo/Marakwet": "05",
        "Embu": "06",
        "Garissa": "07",
        "Homa Bay": "08",
        "Isiolo": "09",
        "Kajiado": "10",
        "Kakamega": "11",
        "Kericho": "12",
        "Kiambu": "13",
        "Kilifi": "14",
        "Kirinyaga": "15",
        "Kisii": "16",
        "Kisumu": "17",
        "Kitui": "18",
        "Kwale": "19",
        "Laikipia": "20",
        "Lamu": "21",
        "Machakos": "22",
        "Makueni": "23",
        "Mandera": "24",
        "Marsabit": "25",
        "Meru": "26",
        "Migori": "27",
        "Mombasa": "28",
        "Murang'a": "29",
        "Nairobi City": "30",
        "Nakuru": "31",
        "Nandi": "32",
        "Narok": "33",
        "Nyamira": "34",
        "Nyandarua": "35",
        "Nyeri": "36",
        "Siaya": "38",
        "Taita/Taveta": "39",
        "Tharaka-Nithi": "41",
        "Trans Nzoia": "42",
        "Turkana": "43",
        "Uasin Gishu": "44",
        "Wajir": "46",
    },
    "KG": {
        "Batken": "B",
        "Bishkek": "GB",
        "Chuy": "C",
        "Jalal-Abad": "J",
        "Naryn": "N",
        "Osh": "GO",
        "Talas": "T",
        "Ysyk-Kol": "Y",
    },
    "KH": {
        "Baat Dambang": "2",
        "Banteay Mean Chey": "1",
        "Kampong Chaam": "3",
        "Kampong Chhnang": "4",
        "Kampong Spueu": "5",
        "Kampong Thum": "6",
        "Kampot": "7",
        "Kandaal": "8",
        "Kaoh Kong": "9",
        "Kracheh": "10",
        "Krong Kaeb": "23",
        "Krong Pailin": "24",
        "Krong Preah Sihanouk": "18",
        "Mondol Kiri": "11",
        "Otdar Mean Chey": "22",
        "Phnom Penh": "12",
        "Pousaat": "15",
        "Prey Veaeng": "14",
        "Rotanak Kiri": "16",
        "Siem Reab": "17",
        "Svaay Rieng": "20",
        "Taakaev": "21",
    },
    "KI": {"Gilbert Islands": "G", "Line Islands": "L"},
    "KM": {"Grande Comore": "G"},
    "KN": {
        "Saint Anne Sandy Point": "02",
        "Saint George Basseterre": "03",
        "Saint James Windward": "05",
        "Saint John Capisterre": "06",
        "Saint John Figtree": "07",
        "Saint Mary Cayon": "08",
        "Saint Paul Capisterre": "09",
        "Saint Paul Charlestown": "10",
        "Saint Peter Basseterre": "11",
        "Saint Thomas Lowland": "12",
        "Saint Thomas Middle Island": "13",
    },
    "KP": {"P'yongyang": "01"},
    "KR": {
        "Busan-gwangyeoksi": "26",
        "Chungcheongbuk-do": "43",
        "Chungcheongnam-do": "44",
        "Daegu-gwangyeoksi": "27",
        "Daejeon-gwangyeoksi": "30",
        "Gangwon-do": "42",
        "Gwangju-gwangyeoksi": "29",
        "Gyeonggi-do": "41",
        "Gyeongsangbuk-do": "47",
        "Gyeongsangnam-do": "48",
        "Incheon-gwangyeoksi": "28",
        "Jeju-teukbyeoljachido": "49",
        "Jeollabuk-do": "45",
        "Jeollanam-do": "46",
        "Seoul-teukbyeolsi": "11",
        "Ulsan-gwangyeoksi": "31",
    },
    "KW": {
        "Al 'Asimah": "KU",
        "Al Ahmadi": "AH",
        "Al Farwaniyah": "FA",
        "Al Jahra'": "JA",
        "Hawalli": "HA",
        "Mubarak al Kabir": "MU",
    },
    "KY": {"Cayman Islands": ""},
    "KZ": {
        "Almaty": "ALA",
        "Almaty oblysy": "ALM",
        "Aqmola oblysy": "AKM",
        "Aqtobe oblysy": "AKT",
        "Astana": "AST",
        "Atyrau oblysy": "ATY",
        "Batys Qazaqstan oblysy": "ZAP",
        "Bayqongyr": "BAY",
        "Mangghystau oblysy": "MAN",
        "Ongtustik Qazaqstan oblysy": "YUZ",
        "Pavlodar oblysy": "PAV",
        "Qaraghandy oblysy": "KAR",
        "Qostanay oblysy": "KUS",
        "Qyzylorda oblysy": "KZY",
        "Shyghys Qazaqstan oblysy": "VOS",
        "Soltustik Qazaqstan oblysy": "SEV",
        "Zhambyl oblysy": "ZHA",
    },
    "LA": {
        "Attapu": "AT",
        "Champasak": "CH",
        "Houaphan": "HO",
        "Khammouan": "KH",
        "Louang Namtha": "LM",
        "Louangphabang": "LP",
        "Oudomxai": "OU",
        "Salavan": "SL",
        "Savannakhet": "SV",
        "Viangchan": "VI",
        "Xaignabouli": "XA",
        "Xekong": "XE",
        "Xiangkhouang": "XI",
    },
    "LB": {
        "Aakkar": "AK",
        "Baalbek-Hermel": "BH",
        "Beqaa": "BI",
        "Beyrouth": "BA",
        "Liban-Nord": "AS",
        "Liban-Sud": "JA",
        "Mont-Liban": "JL",
        "Nabatiye": "NA",
    },
    "LC": {
        "Anse la Raye": "01",
        "Castries": "02",
        "Choiseul": "03",
        "Dennery": "05",
        "Gros Islet": "06",
        "Laborie": "07",
        "Micoud": "08",
        "Soufriere": "10",
        "Vieux Fort": "11",
    },
    "LI": {
        "Balzers": "01",
        "Eschen": "02",
        "Gamprin": "03",
        "Mauren": "04",
        "Planken": "05",
        "Ruggell": "06",
        "Schaan": "07",
        "Schellenberg": "08",
        "Triesen": "09",
        "Triesenberg": "10",
        "Vaduz": "11",
    },
    "LK": {
        "Central Province": "2",
        "Eastern Province": "5",
        "North Central Province": "7",
        "North Western Province": "6",
        "Northern Province": "4",
        "Sabaragamuwa Province": "9",
        "Southern Province": "3",
        "Uva Province": "8",
        "Western Province": "1",
    },
    "LR": {
        "Grand Bassa": "GB",
        "Grand Gedeh": "GG",
        "Margibi": "MG",
        "Maryland": "MY",
        "Montserrado": "MO",
        "Nimba": "NI",
        "Sinoe": "SI",
    },
    "LS": {"Berea": "D", "Leribe": "C", "Mafeteng": "E", "Maseru": "A", "Quthing": "G"},
    "LT": {
        "Alytaus apskritis": "AL",
        "Kauno apskritis": "KU",
        "Klaipedos apskritis": "KL",
        "Marijampoles apskritis": "MR",
        "Panevezio apskritis": "PN",
        "Siauliu apskritis": "SA",
        "Taurages apskritis": "TA",
        "Telsiu apskritis": "TE",
        "Utenos apskritis": "UT",
        "Vilniaus apskritis": "VL",
    },
    "LU": {"Diekirch": "DI", "Grevenmacher": "GR", "Luxembourg": "LU"},
    "LV": {
        "Adazu novads": "011",
        "Aglonas novads": "001",
        "Aizkraukles novads": "002",
        "Aizputes novads": "003",
        "Alojas novads": "005",
        "Aluksnes novads": "007",
        "Babites novads": "012",
        "Baldones novads": "013",
        "Balvu novads": "015",
        "Bauskas novads": "016",
        "Beverinas novads": "017",
        "Brocenu novads": "018",
        "Carnikavas novads": "020",
        "Cesu novads": "022",
        "Cesvaines novads": "021",
        "Daugavpils novads": "025",
        "Dobeles novads": "026",
        "Dundagas novads": "027",
        "Erglu novads": "030",
        "Gulbenes novads": "033",
        "Iecavas novads": "034",
        "Ikskiles novads": "035",
        "Incukalna novads": "037",
        "Jaunjelgavas novads": "038",
        "Jaunpiebalgas novads": "039",
        "Jaunpils novads": "040",
        "Jekabpils novads": "042",
        "Jelgava": "JEL",
        "Jelgavas novads": "041",
        "Jurmala": "JUR",
        "Kekavas novads": "052",
        "Kokneses novads": "046",
        "Kraslavas novads": "047",
        "Kuldigas novads": "050",
        "Lielvardes novads": "053",
        "Liepaja": "LPX",
        "Limbazu novads": "054",
        "Livanu novads": "056",
        "Lubanas novads": "057",
        "Ludzas novads": "058",
        "Madonas novads": "059",
        "Malpils novads": "061",
        "Nauksenu novads": "064",
        "Ogres novads": "067",
        "Olaines novads": "068",
        "Ozolnieku novads": "069",
        "Preilu novads": "073",
        "Rezeknes novads": "077",
        "Riebinu novads": "078",
        "Riga": "RIX",
        "Rojas novads": "079",
        "Ropazu novads": "080",
        "Rundales novads": "083",
        "Salacgrivas novads": "086",
        "Salaspils novads": "087",
        "Saldus novads": "088",
        "Saulkrastu novads": "089",
        "Sejas novads": "090",
        "Siguldas novads": "091",
        "Skrundas novads": "093",
        "Stopinu novads": "095",
        "Strencu novads": "096",
        "Talsu novads": "097",
        "Tukuma novads": "099",
        "Valkas novads": "101",
        "Valmiera": "VMR",
        "Varkavas novads": "103",
        "Vecumnieku novads": "105",
        "Ventspils novads": "106",
    },
    "LY": {
        "Al Butnan": "BU",
        "Al Jabal al Akhdar": "JA",
        "Al Jabal al Gharbi": "JG",
        "Al Jufrah": "JU",
        "Al Kufrah": "KF",
        "Al Marj": "MJ",
        "Al Marqab": "MB",
        "Al Wahat": "WA",
        "An Nuqat al Khams": "NQ",
        "Az Zawiyah": "ZA",
        "Banghazi": "BA",
        "Darnah": "DR",
        "Misratah": "MI",
        "Murzuq": "MQ",
        "Nalut": "NL",
        "Sabha": "SB",
        "Tarabulus": "TB",
    },
    "MA": {
        "Beni-Mellal-Khenifra": "05",
        "Casablanca-Settat": "06",
        "Draa-Tafilalet": "08",
        "Fes- Meknes": "03",
        "Guelmim-Oued Noun (EH-partial)": "10",
        "L'Oriental": "02",
        "Laayoune-Sakia El Hamra (EH-partial)": "11",
        "Marrakech-Safi": "07",
        "Rabat-Sale-Kenitra": "04",
        "Souss-Massa": "09",
        "Tanger-Tetouan-Al Hoceima": "01",
    },
    "MC": {
        "Fontvieille": "FO",
        "La Condamine": "CO",
        "Monaco-Ville": "MO",
        "Monte-Carlo": "MC",
        "Saint-Roman": "SR",
    },
    "MD": {
        "Anenii Noi": "AN",
        "Balti": "BA",
        "Basarabeasca": "BS",
        "Bender": "BD",
        "Briceni": "BR",
        "Cahul": "CA",
        "Calarasi": "CL",
        "Cantemir": "CT",
        "Causeni": "CS",
        "Chisinau": "CU",
        "Cimislia": "CM",
        "Criuleni": "CR",
        "Donduseni": "DO",
        "Drochia": "DR",
        "Dubasari": "DU",
        "Edinet": "ED",
        "Falesti": "FA",
        "Floresti": "FL",
        "Gagauzia, Unitatea teritoriala autonoma": "GA",
        "Glodeni": "GL",
        "Hincesti": "HI",
        "Ialoveni": "IA",
        "Leova": "LE",
        "Nisporeni": "NI",
        "Ocnita": "OC",
        "Orhei": "OR",
        "Rezina": "RE",
        "Riscani": "RI",
        "Singerei": "SI",
        "Soldanesti": "SD",
        "Soroca": "SO",
        "Stefan Voda": "SV",
        "Stinga Nistrului, unitatea teritoriala din": "SN",
        "Straseni": "ST",
        "Taraclia": "TA",
        "Telenesti": "TE",
        "Ungheni": "UN",
    },
    "ME": {
        "Bar": "02",
        "Berane": "03",
        "Bijelo Polje": "04",
        "Budva": "05",
        "Cetinje": "06",
        "Danilovgrad": "07",
        "Herceg-Novi": "08",
        "Kolasin": "09",
        "Kotor": "10",
        "Niksic": "12",
        "Plav": "13",
        "Pljevlja": "14",
        "Pluzine": "15",
        "Podgorica": "16",
        "Rozaje": "17",
        "Savnik": "18",
        "Tivat": "19",
        "Ulcinj": "20",
        "Zabljak": "21",
    },
    "MF": {"Saint Martin (French Part)": ""},
    "MG": {
        "Antananarivo": "T",
        "Antsiranana": "D",
        "Fianarantsoa": "F",
        "Mahajanga": "M",
        "Toamasina": "A",
        "Toliara": "U",
    },
    "MH": {"Kwajalein": "KWA", "Majuro": "MAJ"},
    "MK": {
        "Aracinovo": "802",
        "Berovo": "201",
        "Bitola": "501",
        "Bogdanci": "401",
        "Bogovinje": "601",
        "Bosilovo": "402",
        "Brvenica": "602",
        "Centar Zupa": "313",
        "Cesinovo-Oblesevo": "210",
        "Debar": "303",
        "Delcevo": "203",
        "Demir Kapija": "103",
        "Dolneni": "503",
        "Gevgelija": "405",
        "Gostivar": "604",
        "Ilinden": "807",
        "Jegunovce": "606",
        "Karbinci": "205",
        "Kavadarci": "104",
        "Kicevo": "307",
        "Kocani": "206",
        "Kratovo": "701",
        "Kriva Palanka": "702",
        "Krivogastani": "504",
        "Krusevo": "505",
        "Kumanovo": "703",
        "Lipkovo": "704",
        "Makedonska Kamenica": "207",
        "Mavrovo i Rostusa": "607",
        "Negotino": "106",
        "Novaci": "507",
        "Novo Selo": "408",
        "Ohrid": "310",
        "Pehcevo": "208",
        "Petrovec": "810",
        "Plasnica": "311",
        "Prilep": "508",
        "Probistip": "209",
        "Radovis": "409",
        "Resen": "509",
        "Rosoman": "107",
        "Skopje": "85",
        "Sopiste": "812",
        "Stip": "211",
        "Struga": "312",
        "Strumica": "410",
        "Studenicani": "813",
        "Sveti Nikole": "108",
        "Tearce": "608",
        "Tetovo": "609",
        "Valandovo": "403",
        "Vasilevo": "404",
        "Veles": "101",
        "Vevcani": "301",
        "Vinica": "202",
        "Vrapciste": "603",
        "Zelenikovo": "806",
        "Zelino": "605",
    },
    "ML": {
        "Bamako": "BKO",
        "Gao": "7",
        "Kayes": "1",
        "Kidal": "8",
        "Koulikoro": "2",
        "Mopti": "5",
        "Segou": "4",
        "Sikasso": "3",
        "Tombouctou": "6",
    },
    "MM": {
        "Ayeyarwady": "07",
        "Bago": "02",
        "Chin": "14",
        "Kachin": "11",
        "Kayah": "12",
        "Kayin": "13",
        "Magway": "03",
        "Mandalay": "04",
        "Mon": "15",
        "Nay Pyi Taw": "18",
        "Sagaing": "01",
        "Shan": "17",
        "Tanintharyi": "05",
        "Yangon": "06",
    },
    "MN": {
        "Bayan-Olgiy": "071",
        "Dornogovi": "063",
        "Govi-Altay": "065",
        "Omnogovi": "053",
        "Orhon": "035",
        "Ovorhangay": "055",
        "Selenge": "049",
        "Tov": "047",
        "Ulaanbaatar": "1",
    },
    "MO": {"Macao": ""},
    "MP": {"Northern Mariana Islands": ""},
    "MQ": {"Martinique": ""},
    "MR": {
        "Dakhlet Nouadhibou": "08",
        "Nouakchott Nord": "14",
        "Tiris Zemmour": "11",
        "Trarza": "06",
    },
    "MS": {"Saint Anthony": "", "Saint Peter": ""},
    "MT": {
        "Attard": "01",
        "Balzan": "02",
        "Birgu": "03",
        "Birkirkara": "04",
        "Birzebbuga": "05",
        "Bormla": "06",
        "Dingli": "07",
        "Fgura": "08",
        "Floriana": "09",
        "Fontana": "10",
        "Gharb": "14",
        "Gharghur": "15",
        "Ghasri": "16",
        "Ghaxaq": "17",
        "Gudja": "11",
        "Gzira": "12",
        "Hamrun": "18",
        "Iklin": "19",
        "Isla": "20",
        "Kalkara": "21",
        "Kercem": "22",
        "Kirkop": "23",
        "Lija": "24",
        "Luqa": "25",
        "Marsa": "26",
        "Marsaskala": "27",
        "Marsaxlokk": "28",
        "Mdina": "29",
        "Mellieha": "30",
        "Mgarr": "31",
        "Mosta": "32",
        "Mqabba": "33",
        "Msida": "34",
        "Mtarfa": "35",
        "Munxar": "36",
        "Nadur": "37",
        "Naxxar": "38",
        "Paola": "39",
        "Pembroke": "40",
        "Pieta": "41",
        "Qala": "42",
        "Qormi": "43",
        "Rabat Gozo": "45",
        "Rabat Malta": "46",
        "Saint John": "49",
        "Saint Julian's": "48",
        "Saint Lucia's": "53",
        "Saint Paul's Bay": "51",
        "Sannat": "52",
        "Santa Venera": "54",
        "Siggiewi": "55",
        "Sliema": "56",
        "Swieqi": "57",
        "Ta' Xbiex": "58",
        "Tarxien": "59",
        "Valletta": "60",
        "Xaghra": "61",
        "Xewkija": "62",
        "Xghajra": "63",
        "Zabbar": "64",
        "Zebbug Gozo": "65",
        "Zejtun": "67",
        "Zurrieq": "68",
    },
    "MU": {
        "Black River": "BL",
        "Flacq": "FL",
        "Grand Port": "GP",
        "Moka": "MO",
        "Pamplemousses": "PA",
        "Plaines Wilhems": "PW",
        "Port Louis": "PL",
        "Riviere du Rempart": "RR",
        "Rodrigues Islands": "RO",
        "Savanne": "SA",
    },
    "MV": {
        "Alifu Alifu": "02",
        "Baa": "20",
        "Dhaalu": "17",
        "Gaafu Dhaalu": "28",
        "Haa Alifu": "07",
        "Haa Dhaalu": "23",
        "Kaafu": "26",
        "Laamu": "05",
        "Maale": "MLE",
        "Meemu": "12",
        "Noonu": "25",
        "Raa": "13",
        "Seenu": "01",
        "Vaavu": "04",
    },
    "MW": {
        "Balaka": "BA",
        "Blantyre": "BL",
        "Dowa": "DO",
        "Lilongwe": "LI",
        "Machinga": "MH",
        "Mangochi": "MG",
        "Mzimba": "MZ",
        "Ntchisi": "NI",
        "Salima": "SA",
        "Zomba": "ZO",
    },
    "MX": {
        "Aguascalientes": "AGU",
        "Baja California": "BCN",
        "Baja California Sur": "BCS",
        "Campeche": "CAM",
        "Chiapas": "CHP",
        "Chihuahua": "CHH",
        "Ciudad de Mexico": "CMX",
        "Coahuila de Zaragoza": "COA",
        "Colima": "COL",
        "Durango": "DUR",
        "Guanajuato": "GUA",
        "Guerrero": "GRO",
        "Hidalgo": "HID",
        "Jalisco": "JAL",
        "Mexico": "MEX",
        "Michoacan de Ocampo": "MIC",
        "Morelos": "MOR",
        "Nayarit": "NAY",
        "Nuevo Leon": "NLE",
        "Oaxaca": "OAX",
        "Puebla": "PUE",
        "Queretaro": "QUE",
        "Quintana Roo": "ROO",
        "San Luis Potosi": "SLP",
        "Sinaloa": "SIN",
        "Sonora": "SON",
        "Tabasco": "TAB",
        "Tamaulipas": "TAM",
        "Tlaxcala": "TLA",
        "Veracruz de Ignacio de la Llave": "VER",
        "Yucatan": "YUC",
        "Zacatecas": "ZAC",
    },
    "MY": {
        "Johor": "01",
        "Kedah": "02",
        "Kelantan": "03",
        "Melaka": "04",
        "Negeri Sembilan": "05",
        "Pahang": "06",
        "Perak": "08",
        "Perlis": "09",
        "Pulau Pinang": "07",
        "Sabah": "12",
        "Sarawak": "13",
        "Selangor": "10",
        "Terengganu": "11",
        "Wilayah Persekutuan Kuala Lumpur": "14",
        "Wilayah Persekutuan Labuan": "15",
        "Wilayah Persekutuan Putrajaya": "16",
    },
    "MZ": {
        "Cabo Delgado": "P",
        "Gaza": "G",
        "Inhambane": "I",
        "Manica": "B",
        "Maputo": "L",
        "Nampula": "N",
        "Niassa": "A",
        "Sofala": "S",
        "Tete": "T",
        "Zambezia": "Q",
    },
    "NC": {"Province Nord": "", "Province Sud": ""},
    "NE": {
        "Agadez": "1",
        "Diffa": "2",
        "Dosso": "3",
        "Niamey": "8",
        "Tahoua": "5",
        "Tillaberi": "6",
        "Zinder": "7",
    },
    "NF": {"Norfolk Island": ""},
    "NG": {
        "Abia": "AB",
        "Abuja Federal Capital Territory": "FC",
        "Adamawa": "AD",
        "Akwa Ibom": "AK",
        "Anambra": "AN",
        "Bauchi": "BA",
        "Bayelsa": "BY",
        "Benue": "BE",
        "Borno": "BO",
        "Cross River": "CR",
        "Delta": "DE",
        "Ebonyi": "EB",
        "Edo": "ED",
        "Ekiti": "EK",
        "Enugu": "EN",
        "Gombe": "GO",
        "Imo": "IM",
        "Jigawa": "JI",
        "Kaduna": "KD",
        "Kano": "KN",
        "Katsina": "KT",
        "Kebbi": "KE",
        "Kogi": "KO",
        "Kwara": "KW",
        "Lagos": "LA",
        "Nasarawa": "NA",
        "Niger": "NI",
        "Ogun": "OG",
        "Ondo": "ON",
        "Osun": "OS",
        "Oyo": "OY",
        "Plateau": "PL",
        "Rivers": "RI",
        "Sokoto": "SO",
        "Taraba": "TA",
        "Yobe": "YO",
        "Zamfara": "ZA",
    },
    "NI": {
        "Boaco": "BO",
        "Carazo": "CA",
        "Chinandega": "CI",
        "Chontales": "CO",
        "Costa Caribe Norte": "AN",
        "Costa Caribe Sur": "AS",
        "Esteli": "ES",
        "Granada": "GR",
        "Jinotega": "JI",
        "Leon": "LE",
        "Madriz": "MD",
        "Managua": "MN",
        "Masaya": "MS",
        "Matagalpa": "MT",
        "Nueva Segovia": "NS",
        "Rio San Juan": "SJ",
        "Rivas": "RI",
    },
    "NL": {
        "Drenthe": "DR",
        "Flevoland": "FL",
        "Fryslan": "FR",
        "Gelderland": "GE",
        "Groningen": "GR",
        "Limburg": "LI",
        "Noord-Brabant": "NB",
        "Noord-Holland": "NH",
        "Overijssel": "OV",
        "Utrecht": "UT",
        "Zeeland": "ZE",
        "Zuid-Holland": "ZH",
    },
    "NO": {
        "Akershus": "02",
        "Aust-Agder": "09",
        "Buskerud": "06",
        "Finnmark": "20",
        "Hedmark": "04",
        "Hordaland": "12",
        "More og Romsdal": "15",
        "Nord-Trondelag": "17",
        "Nordland": "18",
        "Oppland": "05",
        "Oslo": "03",
        "Ostfold": "01",
        "Rogaland": "11",
        "Sogn og Fjordane": "14",
        "Sor-Trondelag": "16",
        "Telemark": "08",
        "Troms": "19",
        "Vest-Agder": "10",
        "Vestfold": "07",
    },
    "NP": {
        "Bagmati": "BA",
        "Bheri": "BH",
        "Dhawalagiri": "DH",
        "Gandaki": "GA",
        "Janakpur": "JA",
        "Kosi": "KO",
        "Lumbini": "LU",
        "Mahakali": "MA",
        "Mechi": "ME",
        "Narayani": "NA",
        "Rapti": "RA",
        "Sagarmatha": "SA",
        "Seti": "SE",
    },
    "NR": {"Yaren": "14"},
    "NU": {"Niue": ""},
    "NZ": {
        "Auckland": "AUK",
        "Bay of Plenty": "BOP",
        "Canterbury": "CAN",
        "Chatham Islands Territory": "CIT",
        "Gisborne": "GIS",
        "Hawke's Bay": "HKB",
        "Manawatu-Wanganui": "MWT",
        "Marlborough": "MBH",
        "Nelson": "NSN",
        "Northland": "NTL",
        "Otago": "OTA",
        "Southland": "STL",
        "Taranaki": "TKI",
        "Tasman": "TAS",
        "Waikato": "WKO",
        "Wellington": "WGN",
        "West Coast": "WTC",
    },
    "OM": {
        "Ad Dakhiliyah": "DA",
        "Al Buraymi": "BU",
        "Al Wusta": "WU",
        "Az Zahirah": "ZA",
        "Janub al Batinah": "BJ",
        "Janub ash Sharqiyah": "SJ",
        "Masqat": "MA",
        "Musandam": "MU",
        "Shamal al Batinah": "BS",
        "Shamal ash Sharqiyah": "SS",
        "Zufar": "ZU",
    },
    "PA": {
        "Bocas del Toro": "1",
        "Chiriqui": "4",
        "Cocle": "2",
        "Colon": "3",
        "Herrera": "6",
        "Los Santos": "7",
        "Ngobe-Bugle": "NB",
        "Panama": "8",
        "Veraguas": "9",
    },
    "PE": {
        "Amazonas": "AMA",
        "Ancash": "ANC",
        "Apurimac": "APU",
        "Arequipa": "ARE",
        "Ayacucho": "AYA",
        "Cajamarca": "CAJ",
        "Cusco": "CUS",
        "El Callao": "CAL",
        "Huancavelica": "HUV",
        "Huanuco": "HUC",
        "Ica": "ICA",
        "Junin": "JUN",
        "La Libertad": "LAL",
        "Lambayeque": "LAM",
        "Lima": "LIM",
        "Loreto": "LOR",
        "Madre de Dios": "MDD",
        "Moquegua": "MOQ",
        "Pasco": "PAS",
        "Piura": "PIU",
        "Puno": "PUN",
        "San Martin": "SAM",
        "Tacna": "TAC",
        "Tumbes": "TUM",
        "Ucayali": "UCA",
    },
    "PF": {
        "Iles Marquises": "",
        "Iles Sous-le-Vent": "",
        "Iles Tuamotu-Gambier": "",
        "Iles du Vent": "",
    },
    "PG": {
        "Bougainville": "NSB",
        "Central": "CPM",
        "Chimbu": "CPK",
        "East New Britain": "EBR",
        "East Sepik": "ESW",
        "Eastern Highlands": "EHG",
        "Madang": "MPM",
        "Manus": "MRL",
        "Milne Bay": "MBA",
        "Morobe": "MPL",
        "National Capital District (Port Moresby)": "NCD",
        "New Ireland": "NIK",
        "Southern Highlands": "SHM",
        "West New Britain": "WBK",
        "West Sepik": "SAN",
        "Western": "WPD",
        "Western Highlands": "WHM",
    },
    "PH": {
        "Abra": "ABR",
        "Agusan del Norte": "AGN",
        "Agusan del Sur": "AGS",
        "Aklan": "AKL",
        "Albay": "ALB",
        "Antique": "ANT",
        "Apayao": "APA",
        "Aurora": "AUR",
        "Basilan": "BAS",
        "Bataan": "BAN",
        "Batanes": "BTN",
        "Batangas": "BTG",
        "Benguet": "BEN",
        "Biliran": "BIL",
        "Bohol": "BOH",
        "Bukidnon": "BUK",
        "Bulacan": "BUL",
        "Cagayan": "CAG",
        "Camarines Norte": "CAN",
        "Camarines Sur": "CAS",
        "Camiguin": "CAM",
        "Capiz": "CAP",
        "Catanduanes": "CAT",
        "Cavite": "CAV",
        "Cebu": "CEB",
        "Compostela Valley": "COM",
        "Cotabato": "NCO",
        "Davao Oriental": "DAO",
        "Davao del Norte": "DAV",
        "Davao del Sur": "DAS",
        "Dinagat Islands": "DIN",
        "Eastern Samar": "EAS",
        "Guimaras": "GUI",
        "Ifugao": "IFU",
        "Ilocos Norte": "ILN",
        "Ilocos Sur": "ILS",
        "Iloilo": "ILI",
        "Isabela": "ISA",
        "Kalinga": "KAL",
        "La Union": "LUN",
        "Laguna": "LAG",
        "Lanao del Norte": "LAN",
        "Lanao del Sur": "LAS",
        "Leyte": "LEY",
        "Maguindanao": "MAG",
        "Marinduque": "MAD",
        "Masbate": "MAS",
        "Mindoro Occidental": "MDC",
        "Mindoro Oriental": "MDR",
        "Misamis Occidental": "MSC",
        "Misamis Oriental": "MSR",
        "Mountain Province": "MOU",
        "National Capital Region": "00",
        "Negros Occidental": "NEC",
        "Negros Oriental": "NER",
        "Northern Samar": "NSA",
        "Nueva Ecija": "NUE",
        "Nueva Vizcaya": "NUV",
        "Palawan": "PLW",
        "Pampanga": "PAM",
        "Pangasinan": "PAN",
        "Quezon": "QUE",
        "Quirino": "QUI",
        "Rizal": "RIZ",
        "Romblon": "ROM",
        "Samar": "WSA",
        "Sarangani": "SAR",
        "Siquijor": "SIG",
        "Sorsogon": "SOR",
        "South Cotabato": "SCO",
        "Southern Leyte": "SLE",
        "Sultan Kudarat": "SUK",
        "Sulu": "SLU",
        "Surigao del Norte": "SUN",
        "Surigao del Sur": "SUR",
        "Tarlac": "TAR",
        "Tawi-Tawi": "TAW",
        "Zambales": "ZMB",
        "Zamboanga Sibugay": "ZSI",
        "Zamboanga del Norte": "ZAN",
        "Zamboanga del Sur": "ZAS",
    },
    "PK": {
        "Azad Jammu and Kashmir": "JK",
        "Balochistan": "BA",
        "Federally Administered Tribal Areas": "TA",
        "Gilgit-Baltistan": "GB",
        "Islamabad": "IS",
        "Khyber Pakhtunkhwa": "KP",
        "Punjab": "PB",
        "Sindh": "SD",
    },
    "PL": {
        "Dolnoslaskie": "02",
        "Kujawsko-pomorskie": "04",
        "Lodzkie": "10",
        "Lubelskie": "06",
        "Lubuskie": "08",
        "Malopolskie": "12",
        "Mazowieckie": "14",
        "Opolskie": "16",
        "Podkarpackie": "18",
        "Podlaskie": "20",
        "Pomorskie": "22",
        "Slaskie": "24",
        "Swietokrzyskie": "26",
        "Warminsko-mazurskie": "28",
        "Wielkopolskie": "30",
        "Zachodniopomorskie": "32",
    },
    "PM": {"Saint Pierre and Miquelon": ""},
    "PR": {
        "Adjuntas": "",
        "Aguada": "",
        "Aguadilla": "",
        "Aguas Buenas": "",
        "Aibonito": "",
        "Anasco": "",
        "Arecibo": "",
        "Arroyo": "",
        "Barceloneta": "",
        "Barranquitas": "",
        "Bayamon": "",
        "Cabo Rojo": "",
        "Caguas": "",
        "Camuy": "",
        "Canovanas": "",
        "Carolina": "",
        "Catano": "",
        "Cayey": "",
        "Ceiba": "",
        "Ciales": "",
        "Cidra": "",
        "Coamo": "",
        "Comerio": "",
        "Corozal": "",
        "Culebra": "",
        "Dorado": "",
        "Fajardo": "",
        "Florida": "",
        "Guanica": "",
        "Guayama": "",
        "Guayanilla": "",
        "Guaynabo": "",
        "Gurabo": "",
        "Hatillo": "",
        "Hormigueros": "",
        "Humacao": "",
        "Isabela": "",
        "Juana Diaz": "",
        "Lajas": "",
        "Lares": "",
        "Las Marias": "",
        "Las Piedras": "",
        "Loiza": "",
        "Luquillo": "",
        "Manati": "",
        "Maricao": "",
        "Mayaguez": "",
        "Moca": "",
        "Morovis": "",
        "Municipio de Jayuya": "",
        "Municipio de Juncos": "",
        "Naguabo": "",
        "Naranjito": "",
        "Patillas": "",
        "Penuelas": "",
        "Ponce": "",
        "Quebradillas": "",
        "Rincon": "",
        "Rio Grande": "",
        "Sabana Grande": "",
        "Salinas": "",
        "San German": "",
        "San Juan": "",
        "San Lorenzo": "",
        "San Sebastian": "",
        "Santa Isabel Municipio": "",
        "Toa Alta": "",
        "Toa Baja": "",
        "Trujillo Alto": "",
        "Utuado": "",
        "Vega Alta": "",
        "Vega Baja": "",
        "Vieques": "",
        "Villalba": "",
        "Yabucoa": "",
        "Yauco": "",
    },
    "PS": {
        "Bethlehem": "BTH",
        "Gaza": "GZA",
        "Hebron": "HBN",
        "Jenin": "JEN",
        "Jericho and Al Aghwar": "JRH",
        "Jerusalem": "JEM",
        "Nablus": "NBS",
        "Qalqilya": "QQA",
        "Ramallah": "RBH",
        "Salfit": "SLT",
        "Tubas": "TBS",
        "Tulkarm": "TKM",
    },
    "PT": {
        "Aveiro": "01",
        "Beja": "02",
        "Braga": "03",
        "Braganca": "04",
        "Castelo Branco": "05",
        "Coimbra": "06",
        "Evora": "07",
        "Faro": "08",
        "Guarda": "09",
        "Leiria": "10",
        "Lisboa": "11",
        "Portalegre": "12",
        "Porto": "13",
        "Regiao Autonoma da Madeira": "30",
        "Regiao Autonoma dos Acores": "20",
        "Santarem": "14",
        "Setubal": "15",
        "Viana do Castelo": "16",
        "Vila Real": "17",
        "Viseu": "18",
    },
    "PW": {
        "Airai": "004",
        "Kayangel": "100",
        "Koror": "150",
        "Melekeok": "212",
        "Ngaraard": "214",
        "Ngardmau": "222",
    },
    "PY": {
        "Alto Paraguay": "16",
        "Alto Parana": "10",
        "Amambay": "13",
        "Asuncion": "ASU",
        "Boqueron": "19",
        "Caaguazu": "5",
        "Caazapa": "6",
        "Canindeyu": "14",
        "Central": "11",
        "Concepcion": "1",
        "Cordillera": "3",
        "Guaira": "4",
        "Itapua": "7",
        "Misiones": "8",
        "Neembucu": "12",
        "Paraguari": "9",
        "Presidente Hayes": "15",
        "San Pedro": "2",
    },
    "QA": {
        "Ad Dawhah": "DA",
        "Al Khawr wa adh Dhakhirah": "KH",
        "Al Wakrah": "WA",
        "Ar Rayyan": "RA",
        "Ash Shamal": "MS",
        "Az Za'ayin": "ZA",
        "Umm Salal": "US",
    },
    "RE": {"Reunion": ""},
    "RO": {
        "Alba": "AB",
        "Arad": "AR",
        "Arges": "AG",
        "Bacau": "BC",
        "Bihor": "BH",
        "Bistrita-Nasaud": "BN",
        "Botosani": "BT",
        "Braila": "BR",
        "Brasov": "BV",
        "Bucuresti": "B",
        "Buzau": "BZ",
        "Calarasi": "CL",
        "Caras-Severin": "CS",
        "Cluj": "CJ",
        "Constanta": "CT",
        "Covasna": "CV",
        "Dambovita": "DB",
        "Dolj": "DJ",
        "Galati": "GL",
        "Giurgiu": "GR",
        "Gorj": "GJ",
        "Harghita": "HR",
        "Hunedoara": "HD",
        "Ialomita": "IL",
        "Iasi": "IS",
        "Ilfov": "IF",
        "Maramures": "MM",
        "Mehedinti": "MH",
        "Mures": "MS",
        "Neamt": "NT",
        "Olt": "OT",
        "Prahova": "PH",
        "Salaj": "SJ",
        "Satu Mare": "SM",
        "Sibiu": "SB",
        "Suceava": "SV",
        "Teleorman": "TR",
        "Timis": "TM",
        "Tulcea": "TL",
        "Valcea": "VL",
        "Vaslui": "VS",
        "Vrancea": "VN",
    },
    "RS": {
        "Beograd": "00",
        "Borski okrug": "14",
        "Branicevski okrug": "11",
        "Jablanicki okrug": "23",
        "Juznobacki okrug": "06",
        "Juznobanatski okrug": "04",
        "Kolubarski okrug": "09",
        "Kosovsko-Mitrovacki okrug": "28",
        "Macvanski okrug": "08",
        "Moravicki okrug": "17",
        "Nisavski okrug": "20",
        "Pcinjski okrug": "24",
        "Pecki okrug": "26",
        "Pirotski okrug": "22",
        "Podunavski okrug": "10",
        "Pomoravski okrug": "13",
        "Prizrenski okrug": "27",
        "Rasinski okrug": "19",
        "Raski okrug": "18",
        "Severnobacki okrug": "01",
        "Severnobanatski okrug": "03",
        "Srednjebanatski okrug": "02",
        "Sremski okrug": "07",
        "Sumadijski okrug": "12",
        "Toplicki okrug": "21",
        "Zajecarski okrug": "15",
        "Zapadnobacki okrug": "05",
        "Zlatiborski okrug": "16",
    },
    "RU": {
        "Adygeya, Respublika": "AD",
        "Altay, Respublika": "AL",
        "Altayskiy kray": "ALT",
        "Amurskaya oblast'": "AMU",
        "Arkhangel'skaya oblast'": "ARK",
        "Astrakhanskaya oblast'": "AST",
        "Bashkortostan, Respublika": "BA",
        "Belgorodskaya oblast'": "BEL",
        "Bryanskaya oblast'": "BRY",
        "Buryatiya, Respublika": "BU",
        "Chechenskaya Respublika": "CE",
        "Chelyabinskaya oblast'": "CHE",
        "Chukotskiy avtonomnyy okrug": "CHU",
        "Chuvashskaya Respublika": "CU",
        "Dagestan, Respublika": "DA",
        "Ingushetiya, Respublika": "IN",
        "Irkutskaya oblast'": "IRK",
        "Ivanovskaya oblast'": "IVA",
        "Kabardino-Balkarskaya Respublika": "KB",
        "Kaliningradskaya oblast'": "KGD",
        "Kalmykiya, Respublika": "KL",
        "Kaluzhskaya oblast'": "KLU",
        "Kamchatskiy kray": "KAM",
        "Karachayevo-Cherkesskaya Respublika": "KC",
        "Kareliya, Respublika": "KR",
        "Kemerovskaya oblast'": "KEM",
        "Khabarovskiy kray": "KHA",
        "Khakasiya, Respublika": "KK",
        "Khanty-Mansiyskiy avtonomnyy okrug": "KHM",
        "Kirovskaya oblast'": "KIR",
        "Komi, Respublika": "KO",
        "Kostromskaya oblast'": "KOS",
        "Krasnodarskiy kray": "KDA",
        "Krasnoyarskiy kray": "KYA",
        "Kurganskaya oblast'": "KGN",
        "Kurskaya oblast'": "KRS",
        "Leningradskaya oblast'": "LEN",
        "Lipetskaya oblast'": "LIP",
        "Magadanskaya oblast'": "MAG",
        "Mariy El, Respublika": "ME",
        "Mordoviya, Respublika": "MO",
        "Moskovskaya oblast'": "MOS",
        "Moskva": "MOW",
        "Murmanskaya oblast'": "MUR",
        "Nenetskiy avtonomnyy okrug": "NEN",
        "Nizhegorodskaya oblast'": "NIZ",
        "Novgorodskaya oblast'": "NGR",
        "Novosibirskaya oblast'": "NVS",
        "Omskaya oblast'": "OMS",
        "Orenburgskaya oblast'": "ORE",
        "Orlovskaya oblast'": "ORL",
        "Penzenskaya oblast'": "PNZ",
        "Permskiy kray": "PER",
        "Primorskiy kray": "PRI",
        "Pskovskaya oblast'": "PSK",
        "Rostovskaya oblast'": "ROS",
        "Ryazanskaya oblast'": "RYA",
        "Saha, Respublika": "SA",
        "Sakhalinskaya oblast'": "SAK",
        "Samarskaya oblast'": "SAM",
        "Sankt-Peterburg": "SPE",
        "Saratovskaya oblast'": "SAR",
        "Severnaya Osetiya, Respublika": "SE",
        "Smolenskaya oblast'": "SMO",
        "Stavropol'skiy kray": "STA",
        "Sverdlovskaya oblast'": "SVE",
        "Tambovskaya oblast'": "TAM",
        "Tatarstan, Respublika": "TA",
        "Tomskaya oblast'": "TOM",
        "Tul'skaya oblast'": "TUL",
        "Tverskaya oblast'": "TVE",
        "Tyumenskaya oblast'": "TYU",
        "Tyva, Respublika": "TY",
        "Udmurtskaya Respublika": "UD",
        "Ul'yanovskaya oblast'": "ULY",
        "Vladimirskaya oblast'": "VLA",
        "Volgogradskaya oblast'": "VGG",
        "Vologodskaya oblast'": "VLG",
        "Voronezhskaya oblast'": "VOR",
        "Yamalo-Nenetskiy avtonomnyy okrug": "YAN",
        "Yaroslavskaya oblast'": "YAR",
        "Yevreyskaya avtonomnaya oblast'": "YEV",
        "Zabaykal'skiy kray": "ZAB",
    },
    "RW": {"Est": "02", "Nord": "03", "Ouest": "04", "Sud": "05", "Ville de Kigali": "01"},
    "SA": {
        "'Asir": "14",
        "Al Bahah": "11",
        "Al Hudud ash Shamaliyah": "08",
        "Al Jawf": "12",
        "Al Madinah al Munawwarah": "03",
        "Al Qasim": "05",
        "Ar Riyad": "01",
        "Ash Sharqiyah": "04",
        "Ha'il": "06",
        "Jazan": "09",
        "Makkah al Mukarramah": "02",
        "Najran": "10",
        "Tabuk": "07",
    },
    "SB": {"Choiseul": "CH", "Guadalcanal": "GU"},
    "SC": {
        "Anse Boileau": "02",
        "Anse aux Pins": "01",
        "Baie Lazare": "06",
        "Beau Vallon": "08",
        "Bel Ombre": "10",
        "Cascade": "11",
        "English River": "16",
        "Grand Anse Mahe": "13",
        "La Digue": "15",
        "Pointe Larue": "20",
        "Takamaka": "23",
    },
    "SD": {
        "Blue Nile": "NB",
        "Gedaref": "GD",
        "Gezira": "GZ",
        "Kassala": "KA",
        "Khartoum": "KH",
        "North Darfur": "DN",
        "North Kordofan": "KN",
        "Northern": "NO",
        "Red Sea": "RS",
        "River Nile": "NR",
        "Sennar": "SI",
        "South Darfur": "DS",
        "South Kordofan": "KS",
        "West Darfur": "DW",
        "White Nile": "NW",
    },
    "SE": {
        "Blekinge lan": "K",
        "Dalarnas lan": "W",
        "Gavleborgs lan": "X",
        "Gotlands lan": "I",
        "Hallands lan": "N",
        "Jamtlands lan": "Z",
        "Jonkopings lan": "F",
        "Kalmar lan": "H",
        "Kronobergs lan": "G",
        "Norrbottens lan": "BD",
        "Orebro lan": "T",
        "Ostergotlands lan": "E",
        "Skane lan": "M",
        "Sodermanlands lan": "D",
        "Stockholms lan": "AB",
        "Uppsala lan": "C",
        "Varmlands lan": "S",
        "Vasterbottens lan": "AC",
        "Vasternorrlands lan": "Y",
        "Vastmanlands lan": "U",
        "Vastra Gotalands lan": "O",
    },
    "SG": {"Singapore": ""},
    "SH": {"Saint Helena": "HL"},
    "SI": {
        "Ajdovscina": "001",
        "Apace": "195",
        "Beltinci": "002",
        "Benedikt": "148",
        "Bistrica ob Sotli": "149",
        "Bled": "003",
        "Bloke": "150",
        "Bohinj": "004",
        "Borovnica": "005",
        "Bovec": "006",
        "Braslovce": "151",
        "Brda": "007",
        "Brezice": "009",
        "Brezovica": "008",
        "Cankova": "152",
        "Celje": "011",
        "Cerklje na Gorenjskem": "012",
        "Cerknica": "013",
        "Cerkno": "014",
        "Cirkulane": "196",
        "Crensovci": "015",
        "Crnomelj": "017",
        "Destrnik": "018",
        "Divaca": "019",
        "Dobje": "154",
        "Dobrepolje": "020",
        "Dobrna": "155",
        "Dobrova-Polhov Gradec": "021",
        "Dobrovnik": "156",
        "Domzale": "023",
        "Dornava": "024",
        "Dravograd": "025",
        "Duplek": "026",
        "Gorje": "207",
        "Gornja Radgona": "029",
        "Gornji Petrovci": "031",
        "Grad": "158",
        "Grosuplje": "032",
        "Hajdina": "159",
        "Hoce-Slivnica": "160",
        "Hodos": "161",
        "Horjul": "162",
        "Hrastnik": "034",
        "Hrpelje-Kozina": "035",
        "Idrija": "036",
        "Ig": "037",
        "Ilirska Bistrica": "038",
        "Ivancna Gorica": "039",
        "Izola": "040",
        "Jesenice": "041",
        "Jursinci": "042",
        "Kamnik": "043",
        "Kanal": "044",
        "Kidricevo": "045",
        "Kobarid": "046",
        "Kobilje": "047",
        "Kocevje": "048",
        "Komen": "049",
        "Komenda": "164",
        "Koper": "050",
        "Kosanjevica na Krki": "197",
        "Kostel": "165",
        "Kranj": "052",
        "Kranjska Gora": "053",
        "Krizevci": "166",
        "Krsko": "054",
        "Kungota": "055",
        "Kuzma": "056",
        "Lasko": "057",
        "Lenart": "058",
        "Lendava": "059",
        "Litija": "060",
        "Ljubljana": "061",
        "Ljutomer": "063",
        "Log-Dragomer": "208",
        "Logatec": "064",
        "Loska Dolina": "065",
        "Lovrenc na Pohorju": "167",
        "Luce": "067",
        "Lukovica": "068",
        "Majsperk": "069",
        "Makole": "198",
        "Maribor": "070",
        "Markovci": "168",
        "Medvode": "071",
        "Menges": "072",
        "Metlika": "073",
        "Mezica": "074",
        "Miklavz na Dravskem Polju": "169",
        "Miren-Kostanjevica": "075",
        "Mirna Pec": "170",
        "Mislinja": "076",
        "Mokronog-Trebelno": "199",
        "Moravce": "077",
        "Mozirje": "079",
        "Murska Sobota": "080",
        "Muta": "081",
        "Naklo": "082",
        "Nazarje": "083",
        "Nova Gorica": "084",
        "Novo Mesto": "085",
        "Odranci": "086",
        "Oplotnica": "171",
        "Ormoz": "087",
        "Piran": "090",
        "Pivka": "091",
        "Podcetrtek": "092",
        "Podlehnik": "172",
        "Poljcane": "200",
        "Polzela": "173",
        "Postojna": "094",
        "Prebold": "174",
        "Preddvor": "095",
        "Prevalje": "175",
        "Ptuj": "096",
        "Puconci": "097",
        "Race-Fram": "098",
        "Radece": "099",
        "Radenci": "100",
        "Radlje ob Dravi": "101",
        "Radovljica": "102",
        "Ravne na Koroskem": "103",
        "Razkrizje": "176",
        "Recica ob Savinji": "209",
        "Rence-Vogrsko": "201",
        "Ribnica": "104",
        "Rogaska Slatina": "106",
        "Rogasovci": "105",
        "Ruse": "108",
        "Salovci": "033",
        "Semic": "109",
        "Sempeter-Vrtojba": "183",
        "Sencur": "117",
        "Sentilj": "118",
        "Sentjernej": "119",
        "Sentjur": "120",
        "Sentrupert": "211",
        "Sevnica": "110",
        "Sezana": "111",
        "Skocjan": "121",
        "Skofja Loka": "122",
        "Skofljica": "123",
        "Slovenj Gradec": "112",
        "Slovenska Bistrica": "113",
        "Slovenske Konjice": "114",
        "Smarje pri Jelsah": "124",
        "Smarjeske Toplice": "206",
        "Smartno ob Paki": "125",
        "Smartno pri Litiji": "194",
        "Sodrazica": "179",
        "Solcava": "180",
        "Sostanj": "126",
        "Starse": "115",
        "Store": "127",
        "Straza": "203",
        "Sveta Trojica v Slovenskih Goricah": "204",
        "Sveti Andraz v Slovenskih Goricah": "182",
        "Sveti Jurij": "116",
        "Sveti Jurij v Slovenskih Goricah": "210",
        "Sveti Tomaz": "205",
        "Tabor": "184",
        "Tisina": "010",
        "Tolmin": "128",
        "Trbovlje": "129",
        "Trebnje": "130",
        "Trnovska Vas": "185",
        "Trzic": "131",
        "Trzin": "186",
        "Turnisce": "132",
        "Velenje": "133",
        "Velika Polana": "187",
        "Velike Lasce": "134",
        "Verzej": "188",
        "Videm": "135",
        "Vipava": "136",
        "Vitanje": "137",
        "Vodice": "138",
        "Vojnik": "139",
        "Vransko": "189",
        "Vrhnika": "140",
        "Vuzenica": "141",
        "Zagorje ob Savi": "142",
        "Zalec": "190",
        "Zavrc": "143",
        "Zelezniki": "146",
        "Zetale": "191",
        "Ziri": "147",
        "Zrece": "144",
        "Zuzemberk": "193",
    },
    "SK": {
        "Banskobystricky kraj": "BC",
        "Bratislavsky kraj": "BL",
        "Kosicky kraj": "KI",
        "Nitriansky kraj": "NI",
        "Presovsky kraj": "PV",
        "Trenciansky kraj": "TC",
        "Trnavsky kraj": "TA",
        "Zilinsky kraj": "ZI",
    },
    "SL": {"Eastern": "E", "Northern": "N", "Western Area": "W"},
    "SM": {"Domagnano": "03", "San Marino": "07", "Serravalle": "09"},
    "SN": {
        "Dakar": "DK",
        "Diourbel": "DB",
        "Fatick": "FK",
        "Kaffrine": "KA",
        "Kaolack": "KL",
        "Louga": "LG",
        "Saint-Louis": "SL",
        "Tambacounda": "TC",
        "Thies": "TH",
        "Ziguinchor": "ZG",
    },
    "SO": {
        "Awdal": "AW",
        "Banaadir": "BN",
        "Bay": "BY",
        "Nugaal": "NU",
        "Shabeellaha Hoose": "SH",
        "Togdheer": "TO",
        "Woqooyi Galbeed": "WO",
    },
    "SR": {
        "Brokopondo": "BR",
        "Commewijne": "CM",
        "Nickerie": "NI",
        "Para": "PR",
        "Paramaribo": "PM",
        "Saramacca": "SA",
        "Sipaliwini": "SI",
        "Wanica": "WA",
    },
    "SS": {
        "Central Equatoria": "EC",
        "Eastern Equatoria": "EE",
        "Lakes": "LK",
        "Northern Bahr el Ghazal": "BN",
        "Unity": "UY",
        "Upper Nile": "NU",
        "Western Equatoria": "EW",
    },
    "ST": {"Principe": "P", "Sao Tome": "S"},
    "SV": {
        "Ahuachapan": "AH",
        "Cabanas": "CA",
        "Chalatenango": "CH",
        "Cuscatlan": "CU",
        "La Libertad": "LI",
        "La Paz": "PA",
        "La Union": "UN",
        "Morazan": "MO",
        "San Miguel": "SM",
        "San Salvador": "SS",
        "San Vicente": "SV",
        "Santa Ana": "SA",
        "Sonsonate": "SO",
        "Usulutan": "US",
    },
    "SX": {"Sint Maarten (Dutch Part)": ""},
    "SY": {
        "Al Hasakah": "HA",
        "Al Ladhiqiyah": "LA",
        "Al Qunaytirah": "QU",
        "Ar Raqqah": "RA",
        "As Suwayda'": "SU",
        "Dar'a": "DR",
        "Dayr az Zawr": "DY",
        "Dimashq": "DI",
        "Halab": "HL",
        "Hamah": "HM",
        "Hims": "HI",
        "Idlib": "ID",
        "Rif Dimashq": "RD",
        "Tartus": "TA",
    },
    "SZ": {"Hhohho": "HH", "Lubombo": "LU", "Manzini": "MA"},
    "TC": {"Turks and Caicos Islands": ""},
    "TD": {
        "Guera": "GR",
        "Hadjer Lamis": "HL",
        "Logone-Occidental": "LO",
        "Ouaddai": "OD",
        "Tibesti": "TI",
        "Ville de Ndjamena": "ND",
    },
    "TG": {"Centrale": "C", "Kara": "K", "Maritime": "M", "Plateaux": "P"},
    "TH": {
        "Amnat Charoen": "37",
        "Ang Thong": "15",
        "Bueng Kan": "38",
        "Buri Ram": "31",
        "Chachoengsao": "24",
        "Chai Nat": "18",
        "Chaiyaphum": "36",
        "Chanthaburi": "22",
        "Chiang Mai": "50",
        "Chiang Rai": "57",
        "Chon Buri": "20",
        "Chumphon": "86",
        "Kalasin": "46",
        "Kamphaeng Phet": "62",
        "Kanchanaburi": "71",
        "Khon Kaen": "40",
        "Krabi": "81",
        "Krung Thep Maha Nakhon": "10",
        "Lampang": "52",
        "Lamphun": "51",
        "Loei": "42",
        "Lop Buri": "16",
        "Mae Hong Son": "58",
        "Maha Sarakham": "44",
        "Mukdahan": "49",
        "Nakhon Nayok": "26",
        "Nakhon Pathom": "73",
        "Nakhon Phanom": "48",
        "Nakhon Ratchasima": "30",
        "Nakhon Sawan": "60",
        "Nakhon Si Thammarat": "80",
        "Nan": "55",
        "Narathiwat": "96",
        "Nong Bua Lam Phu": "39",
        "Nong Khai": "43",
        "Nonthaburi": "12",
        "Pathum Thani": "13",
        "Pattani": "94",
        "Phangnga": "82",
        "Phatthalung": "93",
        "Phayao": "56",
        "Phetchabun": "67",
        "Phetchaburi": "76",
        "Phichit": "66",
        "Phitsanulok": "65",
        "Phra Nakhon Si Ayutthaya": "14",
        "Phrae": "54",
        "Phuket": "83",
        "Prachin Buri": "25",
        "Prachuap Khiri Khan": "77",
        "Ranong": "85",
        "Ratchaburi": "70",
        "Rayong": "21",
        "Roi Et": "45",
        "Sa Kaeo": "27",
        "Sakon Nakhon": "47",
        "Samut Prakan": "11",
        "Samut Sakhon": "74",
        "Samut Songkhram": "75",
        "Saraburi": "19",
        "Satun": "91",
        "Si Sa Ket": "33",
        "Sing Buri": "17",
        "Songkhla": "90",
        "Sukhothai": "64",
        "Suphan Buri": "72",
        "Surat Thani": "84",
        "Surin": "32",
        "Tak": "63",
        "Trang": "92",
        "Trat": "23",
        "Ubon Ratchathani": "34",
        "Udon Thani": "41",
        "Uthai Thani": "61",
        "Uttaradit": "53",
        "Yala": "95",
        "Yasothon": "35",
    },
    "TJ": {
        "Dushanbe": "DU",
        "Khatlon": "KT",
        "Kuhistoni Badakhshon": "GB",
        "Nohiyahoi Tobei Jumhuri": "RA",
        "Sughd": "SU",
    },
    "TK": {"Tokelau": ""},
    "TL": {"Ainaro": "AN", "Cova Lima": "CO", "Dili": "DI"},
    "TM": {"Ahal": "A", "Balkan": "B", "Dasoguz": "D", "Lebap": "L", "Mary": "M"},
    "TN": {
        "Beja": "31",
        "Ben Arous": "13",
        "Bizerte": "23",
        "Gabes": "81",
        "Gafsa": "71",
        "Jendouba": "32",
        "Kairouan": "41",
        "Kasserine": "42",
        "Kebili": "73",
        "L'Ariana": "12",
        "La Manouba": "14",
        "Le Kef": "33",
        "Mahdia": "53",
        "Medenine": "82",
        "Monastir": "52",
        "Nabeul": "21",
        "Sfax": "61",
        "Sidi Bouzid": "43",
        "Siliana": "34",
        "Sousse": "51",
        "Tataouine": "83",
        "Tozeur": "72",
        "Tunis": "11",
        "Zaghouan": "22",
    },
    "TO": {"Niuas": "03", "Tongatapu": "04"},
    "TR": {
        "Adana": "01",
        "Adiyaman": "02",
        "Afyonkarahisar": "03",
        "Agri": "04",
        "Aksaray": "68",
        "Amasya": "05",
        "Ankara": "06",
        "Antalya": "07",
        "Ardahan": "75",
        "Artvin": "08",
        "Aydin": "09",
        "Balikesir": "10",
        "Bartin": "74",
        "Batman": "72",
        "Bayburt": "69",
        "Bilecik": "11",
        "Bingol": "12",
        "Bitlis": "13",
        "Bolu": "14",
        "Burdur": "15",
        "Bursa": "16",
        "Canakkale": "17",
        "Cankiri": "18",
        "Corum": "19",
        "Denizli": "20",
        "Diyarbakir": "21",
        "Duzce": "81",
        "Edirne": "22",
        "Elazig": "23",
        "Erzincan": "24",
        "Erzurum": "25",
        "Eskisehir": "26",
        "Gaziantep": "27",
        "Giresun": "28",
        "Gumushane": "29",
        "Hakkari": "30",
        "Hatay": "31",
        "Igdir": "76",
        "Isparta": "32",
        "Istanbul": "34",
        "Izmir": "35",
        "Kahramanmaras": "46",
        "Karabuk": "78",
        "Karaman": "70",
        "Kars": "36",
        "Kastamonu": "37",
        "Kayseri": "38",
        "Kilis": "79",
        "Kirikkale": "71",
        "Kirklareli": "39",
        "Kirsehir": "40",
        "Kocaeli": "41",
        "Konya": "42",
        "Kutahya": "43",
        "Malatya": "44",
        "Manisa": "45",
        "Mardin": "47",
        "Mersin": "33",
        "Mugla": "48",
        "Mus": "49",
        "Nevsehir": "50",
        "Nigde": "51",
        "Ordu": "52",
        "Osmaniye": "80",
        "Rize": "53",
        "Sakarya": "54",
        "Samsun": "55",
        "Sanliurfa": "63",
        "Siirt": "56",
        "Sinop": "57",
        "Sirnak": "73",
        "Sivas": "58",
        "Tekirdag": "59",
        "Tokat": "60",
        "Trabzon": "61",
        "Tunceli": "62",
        "Usak": "64",
        "Van": "65",
        "Yalova": "77",
        "Yozgat": "66",
        "Zonguldak": "67",
    },
    "TT": {
        "Arima": "ARI",
        "Chaguanas": "CHA",
        "Couva-Tabaquite-Talparo": "CTT",
        "Diego Martin": "DMN",
        "Mayaro-Rio Claro": "MRC",
        "Penal-Debe": "PED",
        "Point Fortin": "PTF",
        "Port of Spain": "POS",
        "Princes Town": "PRT",
        "San Fernando": "SFO",
        "San Juan-Laventille": "SJL",
        "Sangre Grande": "SGE",
        "Siparia": "SIP",
        "Tobago": "TOB",
        "Tunapuna-Piarco": "TUP",
    },
    "TV": {"Funafuti": "FUN"},
    "TW": {
        "Changhua": "CHA",
        "Chiayi": "CYQ",
        "Hsinchu": "HSQ",
        "Hualien": "HUA",
        "Kaohsiung": "KHH",
        "Keelung": "KEE",
        "Kinmen": "KIN",
        "Lienchiang": "LIE",
        "Miaoli": "MIA",
        "Nantou": "NAN",
        "New Taipei": "NWT",
        "Penghu": "PEN",
        "Pingtung": "PIF",
        "Taichung": "TXG",
        "Tainan": "TNN",
        "Taipei": "TPE",
        "Taitung": "TTT",
        "Taoyuan": "TAO",
        "Yilan": "ILA",
        "Yunlin": "YUN",
    },
    "TZ": {
        "Arusha": "01",
        "Dar es Salaam": "02",
        "Dodoma": "03",
        "Geita": "27",
        "Iringa": "04",
        "Kagera": "05",
        "Kaskazini Unguja": "07",
        "Katavi": "28",
        "Kigoma": "08",
        "Kilimanjaro": "09",
        "Kusini Pemba": "10",
        "Kusini Unguja": "11",
        "Lindi": "12",
        "Manyara": "26",
        "Mara": "13",
        "Mbeya": "14",
        "Mjini Magharibi": "15",
        "Morogoro": "16",
        "Mtwara": "17",
        "Mwanza": "18",
        "Njombe": "29",
        "Pwani": "19",
        "Rukwa": "20",
        "Ruvuma": "21",
        "Shinyanga": "22",
        "Simiyu": "30",
        "Singida": "23",
        "Tabora": "24",
        "Tanga": "25",
    },
    "UA": {
        "Avtonomna Respublika Krym": "43",
        "Cherkaska oblast": "71",
        "Chernihivska oblast": "74",
        "Chernivetska oblast": "77",
        "Dnipropetrovska oblast": "12",
        "Donetska oblast": "14",
        "Ivano-Frankivska oblast": "26",
        "Kharkivska oblast": "63",
        "Khersonska oblast": "65",
        "Khmelnytska oblast": "68",
        "Kirovohradska oblast": "35",
        "Kyiv": "30",
        "Kyivska oblast": "32",
        "Luhanska oblast": "09",
        "Lvivska oblast": "46",
        "Mykolaivska oblast": "48",
        "Odeska oblast": "51",
        "Poltavska oblast": "53",
        "Rivnenska oblast": "56",
        "Sevastopol": "40",
        "Sumska oblast": "59",
        "Ternopilska oblast": "61",
        "Vinnytska oblast": "05",
        "Volynska oblast": "07",
        "Zakarpatska oblast": "21",
        "Zaporizka oblast": "23",
        "Zhytomyrska oblast": "18",
    },
    "UG": {
        "Amuru": "316",
        "Arua": "303",
        "Bugiri": "201",
        "Buikwe": "117",
        "Bukedea": "219",
        "Buliisa": "416",
        "Buvuma": "120",
        "Gulu": "304",
        "Hoima": "403",
        "Iganga": "203",
        "Jinja": "204",
        "Kabale": "404",
        "Kabarole": "405",
        "Kalangala": "101",
        "Kaliro": "222",
        "Kalungu": "122",
        "Kampala": "102",
        "Kamuli": "205",
        "Kapchorwa": "206",
        "Kasese": "406",
        "Kayunga": "112",
        "Kibaale": "407",
        "Kiboga": "103",
        "Kiruhura": "419",
        "Kitgum": "305",
        "Kumi": "208",
        "Kyenjojo": "415",
        "Lira": "307",
        "Luwero": "104",
        "Masaka": "105",
        "Masindi": "409",
        "Mayuge": "214",
        "Mbale": "209",
        "Mbarara": "410",
        "Mityana": "115",
        "Mpigi": "106",
        "Mukono": "108",
        "Nakaseke": "116",
        "Namayingo": "230",
        "Nwoya": "328",
        "Oyam": "321",
        "Pallisa": "210",
        "Rukungiri": "412",
        "Sironko": "215",
        "Soroti": "211",
        "Wakiso": "113",
    },
    "UM": {"Palmyra Atoll": "95"},
    "US": {
        "Alabama": "AL",
        "Alaska": "AK",
        "Arizona": "AZ",
        "Arkansas": "AR",
        "California": "CA",
        "Colorado": "CO",
        "Connecticut": "CT",
        "Delaware": "DE",
        "District of Columbia": "DC",
        "Florida": "FL",
        "Georgia": "GA",
        "Hawaii": "HI",
        "Idaho": "ID",
        "Illinois": "IL",
        "Indiana": "IN",
        "Iowa": "IA",
        "Kansas": "KS",
        "Kentucky": "KY",
        "Louisiana": "LA",
        "Maine": "ME",
        "Maryland": "MD",
        "Massachusetts": "MA",
        "Michigan": "MI",
        "Minnesota": "MN",
        "Mississippi": "MS",
        "Missouri": "MO",
        "Montana": "MT",
        "Nebraska": "NE",
        "Nevada": "NV",
        "New Hampshire": "NH",
        "New Jersey": "NJ",
        "New Mexico": "NM",
        "New York": "NY",
        "North Carolina": "NC",
        "North Dakota": "ND",
        "Ohio": "OH",
        "Oklahoma": "OK",
        "Oregon": "OR",
        "Pennsylvania": "PA",
        "Rhode Island": "RI",
        "South Carolina": "SC",
        "South Dakota": "SD",
        "Tennessee": "TN",
        "Texas": "TX",
        "Utah": "UT",
        "Vermont": "VT",
        "Virginia": "VA",
        "Washington": "WA",
        "West Virginia": "WV",
        "Wisconsin": "WI",
        "Wyoming": "WY",
    },
    "UY": {
        "Artigas": "AR",
        "Canelones": "CA",
        "Cerro Largo": "CL",
        "Colonia": "CO",
        "Durazno": "DU",
        "Flores": "FS",
        "Florida": "FD",
        "Lavalleja": "LA",
        "Maldonado": "MA",
        "Montevideo": "MO",
        "Paysandu": "PA",
        "Rio Negro": "RN",
        "Rivera": "RV",
        "Rocha": "RO",
        "Salto": "SA",
        "San Jose": "SJ",
        "Soriano": "SO",
        "Tacuarembo": "TA",
        "Treinta y Tres": "TT",
    },
    "UZ": {
        "Andijon": "AN",
        "Buxoro": "BU",
        "Farg'ona": "FA",
        "Jizzax": "JI",
        "Namangan": "NG",
        "Navoiy": "NW",
        "Qashqadaryo": "QA",
        "Qoraqalpog'iston Respublikasi": "QR",
        "Samarqand": "SA",
        "Sirdaryo": "SI",
        "Surxondaryo": "SU",
        "Toshkent": "TK",
        "Xorazm": "XO",
    },
    "VA": {"Vatican City": ""},
    "VC": {
        "Charlotte": "01",
        "Grenadines": "06",
        "Saint David": "03",
        "Saint George": "04",
        "Saint Patrick": "05",
    },
    "VE": {
        "Amazonas": "Z",
        "Anzoategui": "B",
        "Apure": "C",
        "Aragua": "D",
        "Barinas": "E",
        "Bolivar": "F",
        "Carabobo": "G",
        "Cojedes": "H",
        "Delta Amacuro": "Y",
        "Distrito Capital": "A",
        "Falcon": "I",
        "Guarico": "J",
        "Lara": "K",
        "Merida": "L",
        "Miranda": "M",
        "Monagas": "N",
        "Nueva Esparta": "O",
        "Portuguesa": "P",
        "Sucre": "R",
        "Tachira": "S",
        "Trujillo": "T",
        "Vargas": "X",
        "Yaracuy": "U",
        "Zulia": "V",
    },
    "VG": {"Virgin Islands, British": ""},
    "VI": {"Virgin Islands, U.S.": ""},
    "VN": {
        "An Giang": "44",
        "Ba Ria - Vung Tau": "43",
        "Bac Giang": "54",
        "Bac Kan": "53",
        "Bac Lieu": "55",
        "Bac Ninh": "56",
        "Ben Tre": "50",
        "Binh Dinh": "31",
        "Binh Duong": "57",
        "Binh Phuoc": "58",
        "Binh Thuan": "40",
        "Ca Mau": "59",
        "Can Tho": "CT",
        "Cao Bang": "04",
        "Da Nang": "DN",
        "Dak Lak": "33",
        "Dak Nong": "72",
        "Dien Bien": "71",
        "Dong Nai": "39",
        "Dong Thap": "45",
        "Gia Lai": "30",
        "Ha Giang": "03",
        "Ha Nam": "63",
        "Ha Noi": "HN",
        "Ha Tinh": "23",
        "Hai Duong": "61",
        "Hai Phong": "HP",
        "Ho Chi Minh": "SG",
        "Hoa Binh": "14",
        "Hung Yen": "66",
        "Khanh Hoa": "34",
        "Kien Giang": "47",
        "Kon Tum": "28",
        "Lai Chau": "01",
        "Lam Dong": "35",
        "Lang Son": "09",
        "Lao Cai": "02",
        "Long An": "41",
        "Nam Dinh": "67",
        "Nghe An": "22",
        "Ninh Binh": "18",
        "Ninh Thuan": "36",
        "Phu Tho": "68",
        "Phu Yen": "32",
        "Quang Binh": "24",
        "Quang Nam": "27",
        "Quang Ngai": "29",
        "Quang Ninh": "13",
        "Quang Tri": "25",
        "Soc Trang": "52",
        "Son La": "05",
        "Tay Ninh": "37",
        "Thai Binh": "20",
        "Thai Nguyen": "69",
        "Thanh Hoa": "21",
        "Thua Thien-Hue": "26",
        "Tien Giang": "46",
        "Tra Vinh": "51",
        "Tuyen Quang": "07",
        "Vinh Long": "49",
        "Vinh Phuc": "70",
        "Yen Bai": "06",
    },
    "VU": {"Shefa": "SEE", "Tafea": "TAE", "Torba": "TOB"},
    "WF": {"Sigave": "SG", "Uvea": "UV"},
    "WS": {"Atua": "AT", "Fa'asaleleaga": "FA", "Tuamasaga": "TU"},
    "YE": {
        "'Adan": "AD",
        "'Amran": "AM",
        "Abyan": "AB",
        "Ad Dali'": "DA",
        "Al Bayda'": "BA",
        "Al Hudaydah": "HU",
        "Al Jawf": "JA",
        "Al Mahwit": "MW",
        "Amanat al 'Asimah": "SA",
        "Dhamar": "DH",
        "Hadramawt": "HD",
        "Ibb": "IB",
        "Lahij": "LA",
        "Ma'rib": "MA",
        "Sa'dah": "SD",
        "San'a'": "SN",
        "Shabwah": "SH",
        "Ta'izz": "TA",
    },
    "YT": {"Mamoudzou": "", "Mtsamboro": "", "Ouangani": "", "Pamandzi": "", "Sada": ""},
    "ZA": {
        "Eastern Cape": "EC",
        "Free State": "FS",
        "Gauteng": "GP",
        "Kwazulu-Natal": "KZN",
        "Limpopo": "LP",
        "Mpumalanga": "MP",
        "North-West": "NW",
        "Northern Cape": "NC",
        "Western Cape": "WC",
    },
    "ZM": {
        "Central": "02",
        "Copperbelt": "08",
        "Eastern": "03",
        "Luapula": "04",
        "Lusaka": "09",
        "North-Western": "06",
        "Northern": "05",
        "Southern": "07",
        "Western": "01",
    },
    "ZW": {
        "Bulawayo": "BU",
        "Harare": "HA",
        "Manicaland": "MA",
        "Mashonaland Central": "MC",
        "Mashonaland East": "ME",
        "Mashonaland West": "MW",
        "Masvingo": "MV",
        "Matabeleland North": "MN",
        "Matabeleland South": "MS",
        "Midlands": "MI",
    },
}

MAP_CITY_TO_CODE: dict[str:str] = {
    key: value
    for cities in cities_grouped_by_country.values()
    for key, value in cities.items()
}
ALLOWED_CITY: list[str] = list(MAP_CITY_TO_CODE.keys())
ALLOWED_CITY_CODE: list[str] = list(MAP_CITY_TO_CODE.values())
ALLOWED_COUNTRY_CODE: list[str] = list(cities_grouped_by_country.keys())

# Types
T_COUNTRY_CODE = Literal[*ALLOWED_COUNTRY_CODE]
T_CITY_CODE = Literal[*ALLOWED_CITY_CODE]
T_CITY = Literal[*ALLOWED_CITY]


def validate_city_code(city_code: str) -> None:
    if city_code not in ALLOWED_CITY_CODE:
        raise exceptions.SincproValidationError(
            f"Invalid city code: [{city_code}] allowed values: {ALLOWED_CITY_CODE}"
        )


def validate_country_code(country_code: str) -> None:
    if country_code not in ALLOWED_COUNTRY_CODE:
        raise exceptions.SincproValidationError(
            f"Invalid country code: [{country_code}] allowed values: {ALLOWED_COUNTRY_CODE}"
        )


def validate_city(city: str) -> None:
    if city not in ALLOWED_CITY:
        raise exceptions.SincproValidationError(
            f"Invalid city: [{city}] allowed values: {ALLOWED_CITY}"
        )


CountryCode = new_value_object(NewType("CountryCode", str), validate_country_code)
CityCode = new_value_object(NewType("CityCode", str), validate_city_code)
CityName = new_value_object(NewType("CityName", str), validate_city)
